#!/usr/bin/perl 
#---------------------------------------------------------------------
# $Id: BadOrderMsg.pm 745 2011-06-21 13:30:45Z tm $
#---------------------------------------------------------------------
# Noark::Error::BadOrderMsg - Bad order object.
# 
# First try at 'Extract Object from Data' refactoring.
#
# Author: Thomas Malt <thomas@malt.no>
#---------------------------------------------------------------------

package Noark::Error::BadOrderMsg;

use strict;
use warnings;


=item new

constructor (msg => message)

=cut
sub new {
    my ($proto, %attr) = @_;

    my $class = ref($proto) || $proto;    
    my $self  = {};

    $self->{MSG}       = $attr{msg} || return undef;
    $self->{MANDATORY} = {};
    $self->{MISSING}   = {};
    $self->{FOUNDHASH} = {};
    $self->{FOUNDLIST} = [];
    $self->{ORDERED}   = [];
    $self->{ALL}       = [];

    bless($self, $class);

    $self->parse_msg();

    return $self;
}

=item parse_msg

parses the message

=cut
sub parse_msg {
    my $self = shift;

    my ($list, $re) = $self->{MSG} =~ /Found=\[(.*)\]\s+RE=\[(.*)\]/;

    # If msg is not formatted correctly we return a 0.
    return 0 if not defined $re;

    $re =~ s/\)\?\(/\?,/g; # remove parenthesis and add comma.
    $re =~ s/\(/ /g;       # replace opening parenthesis with space
    $re =~ s/\)\?/\?/g;    # remove closing parenthesis.
    $re =~ s/\)/,/g;       # replace closing parenthesis with comma.
    $re =~ s/\+//g;        # removing plusses (should work)
    $re =~ s/\s+//g;       # remove space

    my @found = split(/,/, $list);
    for (@found) {
        $self->{FOUNDHASH}->{$_} = 1;
    }

    $self->{FOUNDLIST} = \@found;

    @{$self->{ALL}}   = split(/,/, $re);

    for (@{$self->{ALL}}) {
        if (/(.*)\?$/) {
            push(@{$self->{ORDERED}}, $1);
            next;
        }

        $self->{MANDATORY}->{$_} = 1;
        push(@{$self->{ORDERED}}, $_);
    } 

    for (keys %{$self->{MANDATORY}}) {
        $self->{MISSING}->{$_} = 1 if (not $self->{FOUNDHASH}->{$_});
    }

    return 1;
}

=item get_mandatory_attr

Returns a list of mandatory attributes (HASHREF)

=cut
sub get_mandatory_attr {
    my $self = shift;
    
    return $self->{MANDATORY};
}

=item get_missing_mand_attr

Returns missing mandatory attributes

=cut
sub get_missing_mand_attr {
    my $self = shift;

    return $self->{MISSING};
}

=item get_found_attr

Returns found mandatory attributes
=cut
sub get_found_attr {
    my $self = shift;

    return $self->{FOUNDLIST};
}

=item get_ordered_attr

returns ordered attributes

=cut
sub get_ordered_attr {
    my $self = shift;

    return $self->{ORDERED};
}

=item is_missing_mand_attr

Returns true if we are missing mandatory attributes

=cut
sub is_missing_mand_attr {
    my $self = shift;
    
    return (scalar(keys %{$self->{MISSING}}));
}


=item has_found_attr

Returns number of found attr.

=cut
sub has_found_attr {
    my ($self) = shift;

    return scalar(@{$self->{FOUNDLIST}});
}

1;
