#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id: BrokenDocumentReference.pm 739 2011-06-21 08:47:55Z tm $
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#

package Noark::Error::BrokenDocumentReference;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'Referanse til dokument som ikke finnes.';
    $self->{text} = q||;	# Settes av get_text.
    $self->{list} = [];
    $self->{hint} = "Ved eksport av elektroniske dokumenter "
	          . "skal uttrekket inneholde relative "
		  . "adresser til dokumentene.";
    $self->{__key_values} = [qw|line file name|];
    bless ($self, $class);

    return $self;
}

sub get_text {
    my $self = shift;

    # assert(ref($self->{list}) eq 'ARRAY');
    my $list_count = scalar keys %{$self->{__keys}};
    # assert( $list_count >= 1 );

    my $is_plural  = ($list_count > 1) ? 1 : 0;
    my $place    = ($is_plural) ? 'Flere steder' : 'Et sted'; 
    my $document = ($is_plural) ? 'dokumenter'   : 'et dokument';
    my $filename = ($is_plural) ? 'Dokumentene'  : 'Dokumentet';

    $self->{text} = $place.' i fila referereres til '.$document.' som vi '
                  . 'ikke kan '
                  . 'finne i avleveringen.  Jamfr NOARK-4.1 Kapittel '
                  . '15.2.3.  '.$filename.' det refefereres til er:';

    return $self->{text};
}

sub add_file {
    my ($self, $referring_file, $referred_file, $current_line) = @_;

    $self->{FILE} = $referring_file;

    push @{$self->{list}}, [$referring_file, $referred_file, $current_line];

    return 1;
}


sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind+2)."\n\n";
    $msg .= $self->get_list_labels($ind+2);
    
    my $k = $self->{__keys};
    for my $l (sort keys %$k) {
        my $fs = $k->{$l};
        for my $f (sort keys %$fs) {
            my $ns = $fs->{$f};
            for my $n (sort keys %$ns) {
                $msg .= sprintf(
                    "%s  %-12s  %8s  %-40.40s\n", 
                    " " x ($ind+2), 
                    $f, $l, $n 
                );
            }
        }
    }
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %8s  %-40s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        'Filnavn', 'Linje', 'Dokumentnavn'
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 8,
        "-" x 40
    );

    return $str;
}


1;
__END__
