#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------
package Noark::Error::DuplicateKey;

use base ('Noark::Error');

use File::Basename;
use Carp;
use Noark::Schema;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {
        name => 'Duplikat nkkelverdi',
        text => 'Det ble funnet en rad hvor verdien i nkkelraden(e) var ' 
              . 'en duplikat av en tidligere importert rad.',
    };

    $self->{__keys} = {};
    $self->{__schema} = Noark::Schema->new();

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|pk file line table|) {
        if (!defined $args->{$a}) { 
            croak("You must supply a value for '$a' in arguments");
        }
    }

    my $pkname = $self->{__schema}->get_pk_names_as_string($args->{table});

    $self->{__keys}
        ->{$args->{file}}
            ->{$args->{line}}
                ->{$pkname}
                    ->{$args->{pk}} = 1;

    $self->increment_counter();
    return $self;
}

sub to_text {
    my ($self, $section, $indent) = @_;

    $indent ||= 0;

    my $pre = " " x $indent;
    my $msg = $pre;

    $msg .= $section." " if defined($section);
    $msg .= $self->get_name()."\n\n";

    $msg .= $self->__format_text($self->get_text(), $indent)."\n\n";
    $msg .= $self->get_list_labels($indent);

    my $k = $self->{__keys};
    my $l = '';
    for my $file (sort keys %$k) {
        for my $line (sort keys %{$k->{$file}}) {
            for my $pk (keys %{$k->{$file}->{$line}}) {
                for my $value (keys %{$k->{$file}->{$line}->{$pk}}) {
                    $l .= sprintf(
                        "%s  %-12s  %7s  %16.16s == %-24.24s\n",
                        $pre, $file, $line, $pk, $value
                    );
                }
            }
        }
    }

    $msg .= $l;
    return $msg;
}

sub get_text {
    my $self = shift;

    return $self->{text};
}

sub get_name {
    my $self = shift;
    
    return $self->{name};
}

sub get_list_labels {
    my ($self, $indent) = @_;
    $indent ||= 0;

    my $key = "%s  %-12s  %7s  %16s    %-24s\n";
    my $str = sprintf($key, 
                      (" " x $indent), "Filnavn", "Linje", "Nkkel", "Verdi");
    $str   .= sprintf($key, 
                      (" " x $indent), ("-" x 12), ("-" x 7), 
                      ("-" x 16), ("-" x 24));
    
    return $str;
}

1;
  

