#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id$
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::DuplicateTabellinfo;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'Duplisert tabellinfo funnet';
    $self->{text} = 'Det ble funnet flere forekomster av TABELLINFO for '
                  . 'samme tabell i NOARKIH. Dette gjelder:';

    $self->{__key_values} = [qw|line table|];

    return $self;

}


sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort { $a <=> $b } keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {
            $msg .= sprintf(
                "%s  %-24.24s  %8s\n",
                " " x $ind,
                $table, $line
            );
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-24s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabellnavn", "Linje"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 24,
        "-" x 8,
    );

    return $str;
}


1;
