#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------
package Noark::Error::DuplicateUnique;

use base ('Noark::Error');

use File::Basename;
use Carp;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {
        name => 'Duplikat verdi for felt som er UNIQUE',
        text => 'Vi fant en eller flere felt som hadde duplikate verdier '
              . 'der verdien er definert til  vre unik iht. Noark-4.1.'
    };

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|field value datatype file lines|) {
        if (!defined $args->{$a}) {
            croak("You must supply a value for '$a' in arguments");
        }
    }

    $self->{__keys}
        ->{$args->{file}}
            ->{$args->{lines}->[0]}
                ->{$args->{lines}->[1]}
                    ->{$args->{field}}
                        ->{$args->{value}}
                            ->{$args->{datatype}} = 1;

    $self->increment_counter();

    return $self;
}

sub to_text {
    my ($self, $section, $indent) = @_;

    $indent ||= 0;

    my $pre = " " x $indent;
    my $msg = $pre;

    $msg .= $section." " if defined($section);
    $msg .= $self->get_name()."\n\n";

    $msg .= $self->__format_text($self->get_text(), $indent)."\n\n";
    $msg .= $self->get_list_labels($indent);
    
    my $k = $self->{__keys};
    my $l = '';
    for my $file (sort keys %$k) {
        for my $line (sort keys %{$k->{$file}}) {
            for my $lin2 (sort keys %{$k->{$file}->{$line}}) {
                for my $key (keys %{$k->{$file}->{$line}->{$lin2}}) {
                    my $values = $k->{$file}->{$line}->{$lin2}->{$key};
                    for my $value (keys %$values) {
                        my $types = $values->{$value};
                        for my $type (sort keys %$types) {
                            $l .= sprintf(
                                "%s  %-12s  %8s  %8s  %16.16s  %-16.16s\n",
                                $pre, $file, $line, $lin2, $key, $type
                            );
                        }
                    }
                }
            }
        }
    }
    
    $msg .= $l;
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %8s  %8s  %16s  %-16s\n";
    my $str = sprintf(
        $key, 
        " " x $indent, 
        "Filnavn", 
        "Linje 1",
        "Linje 2",
        "Nkkel", 
        "Datatype"
    );
    $str .= sprintf(
        $key, 
        " " x $indent, 
        "-" x 12, 
        "-" x 8,
        "-" x 8,
        "-" x 16,
        "-" x 16
    );
    
    return $str;
}

1;
