#!/usr/bin/perl
#-----------------------------------------------------------------------
# $Id: ExtraAttribute.pm 783 2011-06-24 14:23:43Z tm $
#-----------------------------------------------------------------------
# Noark::Extra::ExtraAttributesError - Object for errors.
#
# Author: Thomas Malt <thomas@malt.no>
#
# 
# fr jvla

package Noark::Error::ExtraAttribute;
use base ('Noark::Error');

use strict;
use warnings;

use YAML::Syck;
use Carp;
use File::Basename;

use Noark::Schema;

sub new {
    my ($proto, %opts) = @_;

    my $s = Noark::Schema->new();
    # croak("The table must be valid") 
    #     if not $s->is_tablename_valid($opts{table});

    my $class = ref($proto) || $proto;
    my $messagefile = 
        dirname($INC{'Noark/Error/ExtraAttribute.pm'}) .
        '/Messages/ExtraAttribute.yaml';

    croak("Messagefile $messagefile is not valid") if ! -r $messagefile;
    my $self = LoadFile($messagefile);
    
    # $self->{table}        = $opts{table};
    $self->{__attributes} = [];
    $self->{__got_ox}     = 0;

    bless($self, $class);
    return $self;
}


sub add_line {
    my ($self, $args) = @_;

    return $self->add_attributes($args);
}

=item add_attributes ($file, $list)

Adds extra attributes to file in file list. If file doesn't exist it
is appended.

Takes a string ($filename), and an arrayref ($list) as arguments.

=cut
sub add_attributes {
    my ($self, $args) = @_;
    
    my $list = $args->{attributes};
    $self->{table} = $args->{table};

    return undef unless scalar(@$list);

    my $schema = Noark::Schema->new();
    my %got    = map { $_ => 1 } @{$self->{__attributes}};
    
    for (@{$list}) {
        next if $got{$_};
        my $a = undef;
        eval {
            $a = $schema->get_attribute($self->{table}, $_);
        };
        next if $@; # Invalid attributes are handled elsewhre
        next if not defined $a;
        # Prune out attributes which are cursive. We report them elsewhere.
        next unless $a->is_exportable();
        
        if ($a->get_requirement eq 'O' && !$a->can_be_null) {
            $self->{__got_ox} = 1;
        }

        push @{$self->{__attributes}}, $_;
    }

    return 1;
}

=item get_attributes

Returns the list of attributes as an arrayref of hasrefs.

=cut
sub get_attributes {
    my $self       = shift;
    my $table      = $self->{table};
    my $schema     = Noark::Schema->new();
    
    my %list = ();
    for (@{$self->{__attributes}}) {
        my $a = $schema->get_attribute($table, $_);
        my $K = $a->is_exportable() 
              ? $a->get_requirement() 
              : '/'.$a->get_requirement().'/';
        my $O = $a->can_be_null() ? ' ' : 'x'; 
        
        $list{$_} = "K=".$K.",O=".$O;
    }

    return \%list;
}

sub get_attributes_for_file {
    my ($self, $file) = @_;
    return @{$self->{__attributes}->{$file}};
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";

    $msg .= $self->__format_text(
        $self->{__got_ox} ? $self->{ifox} : $self->{ifa},
        $ind+2
    );

    $msg .= "\n";
    $msg .= $self->__format_text($self->{text}, $ind+2)."\n\n";
    $msg .= $self->get_list_labels($ind+2);
    
    my $list = $self->get_attributes();
    for my $item (sort keys %$list) {
        $msg .= sprintf(
            "%s  %-24s  %-12s\n", 
            " " x ($ind+2), 
            $item, 
            $list->{$item}
        );
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-24s  %-12s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        'Attributt', 'Krav type'
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 24,
        "-" x 12
    );

    return $str;
}

1;
__END__
