#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------
package Noark::Error::ForeignKey;

use base ('Noark::Error');

use File::Basename;
use Carp;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {};

    $self->{name} = 'Fremmednkkelfeil';
    $self->{text} = 'Det er funnet rad(er) i tabellen med ugyldig, men '
                  . 'obligatorisk, '
                  . 'fremmednkkelreferanse. Verdien manglet i '
                  . 'tabellen det refereres til. Attributtet kan ogs ha blitt ' 
                  . 'ugyldiggjort under database-importen hvis det inneholdt ' 
                  . 'en ugyldig verdi iht. Noark-4.1. Dette gjelder flgende '
                  . 'nkler:';

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|field value requirement ref_field table ref_table|) {
        if (!defined $args->{$a}) {
            croak("You must supply a value for '$a' in arguments");
        }
    }
    
    my $field     = $args->{field};
    my $ref_field = $args->{ref_field};
    my $table     = $args->{table};
    my $ref_table = $args->{ref_table};
    my $value     = $args->{value};
    my $requirement = $args->{requirement};

    $self->{__keys}
        ->{$table}
            ->{$field}
                ->{$ref_table}
                    ->{$ref_field}
                        ->{$value}
                            ->{$requirement} += 1;

    $self->increment_counter();

    return $self;
}

sub to_text {
    my ($self, $section, $ind) = @_;
    $ind ||= 0;

    my $pre = " " x $ind;
    my $msg = $pre;

    $msg .= $section." " if defined $section;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text(), $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    my $k = $self->{__keys};
    my $l = '';

    for my $table (sort keys %$k) {
        my $attrs = $k->{$table};
        for my $attr (sort keys %$attrs) {
            my $reftables = $attrs->{$attr};
            for my $reftable (sort keys %$reftables) {
                my $refattrs = $reftables->{$reftable};
                for my $refattr (sort keys %$refattrs) {
                    my $values = $refattrs->{$refattr};
                    for my $value (sort keys %$values) {
                        my $reqs = $values->{$value};
                        for my $req (sort keys %$reqs) {
                            $l .= sprintf(
                                "%s  %-24.24s  %6s  %-24s  %-8s\n",
                                " " x $ind,
                                $attr." (".$value.")",
                                $reqs->{$req},
                                $reftable." : ".$refattr,
                                $req
                            );
                        }
                    }
                }
            }
        }
    }

    $msg .= $l;
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-24s  %6s  %-24s  %-8s\n";
    my $str = sprintf(
        $key, 
        " " x $indent, 
        "Nkkel (Verdi)",
        "Antall",
        "Referanse",
        "Krav"
    );
    $str .= sprintf(
        $key, 
        " " x $indent, 
        "-" x 24,
        "-" x 6,
        "-" x 24,
        "-" x 8
    );
    
    return $str;
}

1;
