#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id$
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::MissingFildel;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'FIL informasjon mangler TI.FILDEL';
    $self->{text} = "TABELLINFO inneholder feil verdi for TI.ANTFILER. " 
                  . "Arkivsystemet m utbedres slik at riktig antall filer "
                  . "blir rapportert. Dette gjelder:";

    $self->{__key_values} = [qw|line table noarkih_count deposit_count|];

    return $self;

}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {            
            my $ihcounts = $self->{__keys}->{$line}->{$table};
            for my $ihc (sort keys %$ihcounts) {
                my $ficounts = $ihcounts->{$ihc};
                for my $fic (sort keys %$ficounts) {
                    $msg .= sprintf(
                        "%s  %-16.16s  %8s  %9s  %9s\n",
                        " " x $ind,
                        $table, $line, $ihc, $fic
                       );
                }
            }
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-16s  %8s  %9s  %9s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabell", "Linje", "i NOARKIH", "i Avlev."
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 16,
        "-" x 8,
        "-" x 9,
        "-" x 9
    );

    return $str;
}


1;
