#!/usr/bin/perl
#-----------------------------------------------------------------------
# $Id: MissingFileFound.pm 708 2011-06-17 12:27:21Z tm $
#-----------------------------------------------------------------------

package Noark::Error::MissingFileFound;

use strict;
use warnings;

use Noark::Error::MissingFile;
use Carp::Assert;
use Carp;

use base ('Noark::Error::MissingFile');

sub new {
    my ($proto, %opts) = @_;

    my $class = ref($proto) || $proto;
    my $self = {};
    
    $self->{name} = "Forskjell p filnavn i NOARKIH og i avlevering";
    $self->{text} = ""; # Settes av get_text.
    $self->{__keys} = {};
    $self->{__key_values} = [qw|line noarkih_file deposit_file|];

    bless($self, $class); 

    return $self;
}

sub get_text {
    my $self = shift;

    my $many = scalar keys %{$self->{__keys}} > 1 ? 1 : 0;

    my $many_files = ($many) ? 'flere filer' : 'n fil';
    my $many_names = ($many) ? 'Filnavnene'  : 'Filnavnet';

    $self->{text} = "Filnavnet i NOARKIH stemte ikke med filnavnet i "
                  . "avleveringen for $many_files. $many_names er: ";

    return $self->{text};
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort { $a <=> $b } keys %{$self->{__keys}}) {
        for my $file (sort keys %{$self->{__keys}->{$line}}) {
            for my $fil2 (sort keys %{$self->{__keys}->{$line}->{$file}}) {
                $msg .= sprintf(
                    "%s  %-12.12s  %-32.32s  %8s\n",
                    " " x $ind,
                    $file, $fil2, $line
                );
            }
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %-32s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "i NOARKIH", "Navn i avlevering", "Linje"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 32,
        "-" x 8,
    );

    return $str;
}


1;
__END__
