#!/usr/bin/perl
#------------------------------------------------------------------------
# $Id: Null.pm 795 2011-06-28 13:38:32Z tm $
#------------------------------------------------------------------------
package Noark::Error::Null;

use base ('Noark::Error');

use File::Basename;
use Carp;
use Data::Dumper;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {
        name => 'Mangler verdi i felt som krever verdi',
        text => 'Tabellen mangler en eller flere verdier i felt som krever '
              . 'verdi i henhold til Noark-4.1.',
    };

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    $args->{field} || croak("You must supply a value for 'field' in arguments");
    $args->{file}  || croak("You must supply a value for 'file' in arguments");
    $args->{line}  || croak("You must supply a value for 'line' in arguments");

    $self->{__keys}->{$args->{field}}->{$args->{file}}->{$args->{line}} = 1;
    $self->increment_counter();

    return $self;
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $pre = " " x $ind;
    my $msg = $pre;
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    my $k = $self->{__keys};
    my $l = '';

    for my $field (sort keys %$k) {
        my $files = $k->{$field};
        for my $file (sort keys %$files) {
            my $lines = $files->{$file};
            my @list = sort keys %$lines;
            my $count = scalar @list;
            my $first = shift @list if @list;
            $first ||= '';
            my $last  = pop @list if @list;
            $last ||= '';

            $l .= sprintf(
                "%s  %-12s  %-16s  %8s  %8s  %7s\n",
                " " x $ind, $file, $field, $first, $last, $count 
            );
        }
    }
    $msg .= $l;

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %-16s  %8s  %8s  %7s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        qw(Filnavn Felt Frste Siste Antall)
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 16,
        "-" x 8,
        "-" x 8,
        "-" x 7
    );

    return $str;
}

1;
