#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------
package Noark::Error::PotentialDuplicateKey;

use base ('Noark::Error');

use File::Basename;
use YAML::Syck;
use Carp;

use strict;
use warnings;

sub new {
    my ($proto, %args) = @_;

    my $class       = ref($proto) || $proto;
    my $dir         = dirname($INC{'Noark/Error/PotentialDuplicateKey.pm'});
    my $messagefile = $dir.'/Messages/PotentialDuplicateKey.yaml';

    croak("Messagefile $messagefile is not valid") if ! -r $messagefile;
    my $self = LoadFile($messagefile);

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|pk file line norm|) {
        if (!defined $args->{$a}) { 
            croak("You must supply a value for '$a' in arguments");
        }
    }

    $self->{__keys}
        ->{$args->{norm}}
            ->{$args->{file}}
                ->{$args->{pk}}
                    ->{$args->{line}} = 1;

    return 1;
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||=0;
    
    my $msg = " " x $ind;
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    my $k = $self->get_keys();
    my $l = '';
    for my $norm (sort keys %$k) {
        my $files = $k->{$norm};
        for my $file (sort keys %$files) {
            my $keys = $files->{$file};
            for my $pk (sort keys %$keys) {
                my $lines = $keys->{$pk};
                for my $line (sort keys %$lines) {
                    $l .= sprintf(
                        "%s  %-12s  %-16.16s  %8s  %-24.24s\n",
                        " " x $ind,
                        $file, $norm, $line, $pk
                    );
                }
            }
        }
    }
    $msg .= $l;
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %-16s  %8s  %-24s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        qw(Filnavn Norm.Nkkel Linje Nkkel)
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 16,
        "-" x 8,
        "-" x 24
    );

    return $str;
}


sub get_keys {
    my $self = shift;
    return $self->{__keys};
}

1;
