#!/usr/bin/perl
#------------------------------------------------------------------------
# $Id$
#------------------------------------------------------------------------
package Noark::Error::PrimaryKey;

use base ('Noark::Error');

use File::Basename;
use Carp;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {
        name => 'Ugyldig primrnkkel i tabell',
        text => 'Et felt som utgjorde primrnkkelen i tabellen var ikke '
              . 'definert, til tross for at feltet skal vre avlevert '
              . 'iht. Noark-4.1.', 
    };

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $att (qw|pk file line|) {
        if (!defined $args->{$att}) {
            croak("You must supply a value for '$att' in arguments");
        }
    }

    $self->{__keys}->{$args->{pk}}->{$args->{file}}->{$args->{line}} = 1;
    $self->increment_counter();

    return $self;
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $pre = " " x $ind;
    my $msg = $pre;

    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    my $k = $self->{__keys};
    my $l = '';

    for my $key (sort keys %$k) {
        my $files = $k->{$key};
        for my $file (sort keys %$files) {
            my $lines = $files->{$file};
            for my $line (sort {$a <=> $b} keys %$lines) {
                $l .= sprintf(
                    "%s  %-12s  %8s  %-42s\n",
                    $pre, $file, $line, $key
                );
            }
        }
    }

    $msg .= $l;
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %8s  %-42s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        qw(Filnavn Linje Nkkel)
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 8,
        "-" x 42
    );

    return $str;
}

1;
