#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id$
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::RowCount;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'Feil antall poster oppgitt';
    $self->{text} = 'Antall poster oppgitt i NOARKIH stemmer ikke med det som '
                  . 'forekommer i avleveringsfilen:';

    $self->{__key_values} = [qw|line table file noarkih_count file_count|];

    return $self;

}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {            
            for my $file (sort keys %{$self->{__keys}->{$line}->{$table}}) {
                my $ihcounts = $self->{__keys}->{$line}->{$table}->{$file};
                for my $ihc (sort keys %$ihcounts) {
                    my $ficounts = $ihcounts->{$ihc};
                    for my $fic (sort keys %$ficounts) {
                        $msg .= sprintf(
                            "%s  %-16.16s  %8s  %8s  %-12.12s  %8s\n",
                            " " x $ind,
                            $table, $line, $ihc, $file, $fic
                        );
                    }
                }
            }
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-16s  %8s  %8s  %-12s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabell", "Linje", "Antall", "Filnavn", "Antall"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 16,
        "-" x 8,
        "-" x 8,
        "-" x 12,
        "-" x 8,
    );

    return $str;
}


1;
