#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id$
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::RowCountDummy;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'Fant potensiell tom tabell';
    $self->{text} = "Det ble funnet XML-filer i avleveringen med '1' post, "
                  . "mens NOARKIH rapporterte '0' poster. Dette typder p "
                  . "at det er brukt en XML-fil uten innhold for  f "
                  . "eksporten til  validere. Det er bedre  fjerne slike "
                  . "tomme tabeller fra avleveringen fullstendig.";

    $self->{__key_values} = [qw|line table file|];

    return $self;

}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {            
            for my $file (sort keys %{$self->{__keys}->{$line}->{$table}}) {
                $msg .= sprintf(
                    "%s  %-16.16s  %8s  %-12.12s\n",
                    " " x $ind,
                    $table, $line, $file
                );
            }
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-16s  %8s  %-12s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabell", "Linje", "Filnavn"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 16,
        "-" x 8,
        "-" x 12,
    );

    return $str;
}


1;
