#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id$
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::TableName;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%args);

    $self->{name} = 'Ugyldig kortnavn i TI.TABELL';
    $self->{text} = "Det ble brukt tabellnavn i NOARKIH som ikke forekommer "
                  . "i Noark-4.1. Dette tyder p en feil i arkivsystemet som "
                  . "gjr at korrekte avleveringer ikke blir generert.";
    $self->{__key_values} = [qw|line table|];

    return $self;

}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {            
            $msg .= sprintf(
                "%s  %-16.16s  %8s\n",
                " " x $ind,
                $table, $line
               );
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-16s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabellnavn", "Linje"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 16,
        "-" x 8
    );

    return $str;
}


1;
