#!/usr/bin/perl
#-----------------------------------------------------------------------
# $Id: UnknownTable.pm 733 2011-06-20 09:30:16Z tm $
#-----------------------------------------------------------------------
# Author: Thomas Malt <tm@linpro.no>
#
# Copyright (C) 2003-2007 Riksarkivaren
#
package Noark::Error::UnknownTable;
use base ('Noark::Error');

use strict;
use warnings;

use Carp::Assert;

sub new {
    my ($proto, %opts) = @_;

    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new(%opts);
    
    $self->{name} = "Ugyldig tabellnavn i TABELLINFO";
    $self->{text} = "Det ble funnet et eller flere ugyldige tabellnavn. "
                  . "Disse var:";
    $self->{__key_values} = [qw|line table|];

    bless($self, $class); 
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $table (sort keys %{$self->{__keys}->{$line}}) {            
            $msg .= sprintf(
                "%s  %-16.16s  %8s\n",
                " " x $ind,
                $table, $line
               );
        }
    }

    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-16s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Tabellnavn", "Linje"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 16,
        "-" x 8
    );

    return $str;
}



1;
__END__
