#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------
package Noark::Error::ValidData;

use base ('Noark::Error');

use File::Basename;
use Carp;

use strict;
use warnings;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $self = {
        name => 'Ugyldig innhold i attributt',
        text => 'Et eller flere felt i tabellen hadde ugyldig verdi '
              . 'i forhold til datatypen definert i Noark-4.1.',
    };

    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|field value datatype file line|) {
        if (!defined $args->{$a}) {
            croak("You must supply a value for '$a' in arguments");
        }
    }

    $self->{__keys}
        ->{$args->{field}}
            ->{$args->{datatype}}
                ->{$args->{file}}
                    ->{$args->{line}}
                        ->{$args->{value}} = 1;

    $self->increment_counter();

    return $self;
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $pre = " " x $ind;
    my $msg = $pre;

    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    my $k = $self->{__keys};
    my $l = '';

    for my $field (sort keys %$k) {
        my $types = $k->{$field};
        for my $type (sort keys %$types) {
            my $files = $types->{$type};
            for my $file (sort keys %$files) {
                my $lines = $files->{$file};
                my %valuemap = ();

                for my $line (sort {$a <=> $b} keys %$lines) {
                    my $values = $lines->{$line};
                    for my $value (sort keys %$values) {
                        $valuemap{$value} += 1;
                    }
                }

                for my $valuetype (keys %valuemap) {
                    my $count = $valuemap{$valuetype};
                    $l .= sprintf(
                        "%s  %-12s  %-12.12s  %-12.12s  %-16.16s  %8s\n",
                        $pre, $file, $field, $type, $valuetype, $count
                    );
                    
                }
            }
        }
    }

    $msg .= $l;
    return $msg;
}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-12s  %-12s  %-12s  %-16s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        qw(Filnavn Felt Datatype Verdi Antall)
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 12,
        "-" x 12,
        "-" x 12,
        "-" x 16,
        "-" x 8
    );

    return $str;
}


1;
