#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id: WrongFilename.pm 762 2011-06-22 09:47:17Z tm $
#-----------------------------------------------------------------------------
# Errorobject for Noark::Analyzer
#
# Author: Thomas Malt <tm@linpro.no>
#

package Noark::Error::WrongFilename;
use base ('Noark::Error');

use strict;
use warnings;
use Carp::Assert;
use Carp;

sub new {
    my ($proto, %args) = @_;

    my $class = ref($proto) || $proto;
    my $self  = {};

    $self->{name} = 'Filnavn har feil lengde';
    $self->{text} = q||;  # Settes av get_text;
    $self->{__keys} = {};

    bless ($self, $class);

    return $self;
}

sub get_text {
    my $self = shift;

    assert(ref($self->{__keys}) eq 'HASH');

    my $list_count = scalar keys %{$self->{__keys}};

    assert( $list_count >= 1 );

    my $is_plural  = ($list_count > 1) ? 1 : 0;
    my $many_files = ($is_plural) ? 'Flere'      : 'Et'; 
    my $many_names = ($is_plural) ? 'Filnavnene' : 'Filnavnet';

    $self->{text} = "$many_files filnavn i avleveringen er lenger enn "
                  . "8.3 tegn. Jamfr NOARK-4.1 krav K15.4. $many_names er:";

    return $self->{text};
}

sub add_line {
    my ($self, $args) = @_;

    for my $a (qw|noarkih_file deposit_file line|) {
        if (not defined $args->{$a}) { 
            croak("You must supply a value for '$a' in arguments");
        }
    }

    $self->{__keys}->{$args->{line}}
        ->{$args->{noarkih_file}}
            ->{$args->{deposit_file}} = 1;

    return 1;
}

sub get_list {
    my $self = shift;

    return @{$self->{__keys}};
}

sub to_text {
    my ($self, $sec, $ind) = @_;

    $ind ||= 0;

    my $msg = " " x $ind;
    
    $msg .= $sec." " if defined $sec;
    $msg .= $self->get_name()."\n\n";
    $msg .= $self->__format_text($self->get_text, $ind)."\n\n";
    $msg .= $self->get_list_labels($ind);

    for my $line (sort keys %{$self->{__keys}}) {
        for my $file (sort keys %{$self->{__keys}->{$line}}) {
            for my $fil2 (sort keys %{$self->{__keys}->{$line}->{$file}}) {
                $msg .= sprintf(
                    "%s  %-28.28s  %-28.28s  %8s\n",
                    " " x ($ind),
                    $file,
                    $fil2,
                    $line
                );
            }
        }
    }

    return $msg;

}

sub get_list_labels {
    my ($self, $indent) = @_;

    my $key = "%s  %-28s  %-28s  %8s\n";
    my $str = sprintf(
        $key,
        " " x $indent,
        "Navn i NOARKIH", "Navn i avlevering", "Linje"
    );
    $str .= sprintf(
        $key,
        " " x $indent,
        "-" x 28,
        "-" x 28,
        "-" x 8,
    );

    return $str;
}


1;
__END__
