#!/usr/bin/perl
#-----------------------------------------------------------------------
# $Id: XMLMissingMandatoryAttribute.pm 672 2011-06-16 08:44:35Z tm $
#-----------------------------------------------------------------------
# Noark::Extra::XMLMissingMandatoryAttribute - Object for errors.
#
# Author: Thomas Malt <thomas@malt.no>
#

package Noark::Error::XMLMissingMandatoryAttribute;
use base ('Noark::Error');

use strict;
use warnings;

use YAML::Syck;
use Carp;
use File::Basename;

use Noark::Schema;

sub new {
    my ($proto) = @_;

    my $class = ref($proto) || $proto;
    my $messagefile = dirname($INC{'Noark/Error/XMLMissingMandatoryAttribute.pm'}).'/Messages/XMLMissingMandatoryAttribute.yaml';
    croak("Messagefile $messagefile is not valid") if ! -r $messagefile;
    my $self = LoadFile($messagefile);
    
    $self->{__attributes} = [];

    bless($self, $class);
    return $self;
}

=item add_attributes ($file, $list)

Adds extra attributes to file in file list. If file doesn't exist it
is appended.

Takes a string ($filename), and an arrayref ($list) as arguments.

=cut
sub add_attributes {
    my ($self, $attribute, $line) = @_;
    return undef if not defined $attribute;
    return undef if not defined $line;
    return undef if ($line !~ /^\d+$/);
     
    push @{$self->{__attributes}}, {$attribute => $line};
    return 1;
}

=item get_attributes

Returns the list of attributes as an arrayref of hasrefs.

=cut
sub get_attributes {
    my $self       = shift;
    return $self->{__attributes};
}

1;
__END__
