#!/usr/bin/perl
#---------------------------------------------------------------------
# $Id: Helper.pm 493 2007-03-01 10:19:44Z mtr $
#---------------------------------------------------------------------
# Noark::Helper - A module with various functionality.
#
# Author: Thomas Malt <tm@linpro.no>
#
# Copyright (C) 2003  Riksarkivaren.
# Copyright (C) 2003  Linpro AS
# Copyright (C) 2003  Thomas Malt <tm@linpro.no>
#
#---------------------------------------------------------------------

=head1 NAME

Noark::Helper - A Noark module with misc functionality.

=head1 SYNOPSIS

my $foo = NOARK::Helper->new();

$foo->importer_usage();

=head1 DESCRIPTION

This module contains misc functionality not logically placed in any of
the other Noark Modules. It is a general purpose Utility and Helper
module. Hence the name.

=cut

package Noark::Helper;

use strict;
use warnings;

our ($VERSION) = '$Revision: 493 $' =~ /: (\S+)/;

sub new {
    my ($proto) = shift;
    my $class = ref($proto) || $proto;
    my $self = {};

    $self->{VERSION} = $VERSION;
    bless($self, $class);

    return $self;
}



=head1 FUNCTIONS

=over 4

=item importer_usage

Prints helpful(!) message of usage of the importer application.

=cut
sub importer_usage {
    my ($self, $options) = @_;

    print "Usage: $0 [options]\n";
    print "Options:\n";
    my $Bo = "<string>";
    foreach (keys %{$options}) {
        if (/debug/) {
            print "  --debug\t\tTurn debugging on or of.\n";
        } elsif (/help/) {
            print "  --help\t\tPrint this helpful message of usage.\n";
        } else {
            /(.*)\|(.*)=(.*)/;
            print "  --$1, -$2 $Bo\tSet configuraton variable\n";
        } 
    }
}



=item get_datestring ($time)

Returns a formatted date string in the format 2003-10-09 14:34:16
based on time().  If no argument time is given current time is being
used.

  Arguments: $time - time in seconds since epoch.
  Returns:   STRING
  Author:    Thomas Malt <tm@linpro.no>

=cut
sub get_datestring {
    my ($self, $time) = @_;
    $time = time unless $time;

    my ($sec, $min, $hour, $mday, $month, $year, $wday) = localtime($time);
    $year  += 1900;
    $month += 1;
    $mday  = "0".$mday  if ($mday < 10);
    $month = "0".$month if ($month < 10);
    $sec   = "0".$sec   if ($sec < 10);
    $min   = "0".$min   if ($min < 10);
    $hour  = "0".$hour  if ($hour < 10);
    
    my $dstr = "$year-$month-$mday $hour:$min:$sec";
    return $dstr;
}


=back

=cut

1;

#---------------------------------------------------------------------
# $Log$
# Revision 1.1  2005/09/29 13:55:14  tm
# Added all files to repository
#
# Revision 1.1  2004/08/12 14:45:27  elark
# Fixing where its broke.
#
# Revision 1.3  2003/10/15 12:14:48  tm
# Ny versjon av importer og moduler. Frste versjon jeg regner som ferdig.
#
# Revision 1.2  2003/10/10 16:33:09  tm
# Various changes hardening the code. More logging is added. Next step is
# real database interaction.
#
# Revision 1.1  2003/10/10 11:12:45  tm
# Added Helper module for various misc functions. Various updates WIP.
#
