-- -------------------------------------------------------------------
-- $Id: modul_14.4_adm_opp_ark_tabeller.sql 5 2005-09-29 13:55:16Z tm $
-- -------------------------------------------------------------------
-- 14.4 - Modul for administrativ oppbygging og arkivstruktur
-- 
-- Author: Rune Runnest
--         Thomas Malt
--
-- -------------------------------------------------------------------



-- 14.4.1 Administrativ inndeling (admindel)
drop table if exists admindel;

create table admindel(
    ai_id           int(10)                    not null  primary key, -- O
    ai_idfar        int(10)      default null  null,                  -- O
    ai_forkdn       varchar(10)                null,                  -- O
    ai_admkort      varchar(30)                null,		      -- O
    ai_admbet       varchar(70)                null,                  -- O
    ai_type	    varchar(10)                null,                  -- A
    ai_rpgruppe     varchar(30)                null,		      -- A
    ai_fradato      date                       null,		      -- A
    ai_tildato      date                       null                   -- A
)Engine=InnoDB; 



-- 14.4.2 Alias for administrativ enhet (aliasadmenh)
drop table if exists aliasadmenh;

create table aliasadmenh(
    al_admidfra     int(10)         not null,               -- A
    al_admidtil     int(10)         null,                   -- A
    al_merknad      text            null,                   -- A
    primary key (al_admidfra, al_admidtil)
)Engine=InnoDB;



-- 14.4.3 Adresse til administrativ enhet (adradmenh)
drop table if exists adradmenh;

create table adradmenh(
    aa_admid        int(10)	    not null,               -- A
    aa_adrid        int(10)         not null,               -- A
    primary key(aa_admid, aa_adrid)
)Engine=InnoDB;



-- 14.4.4 Enhetstype (enhetstype)
drop table if exists enhetstype;

create table enhetstype(
    et_kode         varchar(10)    not null    primary key, -- A
    et_underen      varchar(10)    null,		    -- A
    et_ltekst       varchar(20)    null,		    -- A
    et_betegn       varchar(70)    null                     -- A
)Engine=InnoDB;



-- 14.4.5 Arkivperiode (arkivperiode)
drop table if exists arkivperiode;

create table arkivperiode(
    ap_arkiv        varchar(10)    not null,                -- O
    ap_periode      int(5)         not null    primary key, -- O
    ap_status       varchar(2)     null,		    -- /O/
    ap_fradato      date           null,		    -- O
    ap_tildato      date           null,                    -- O
    ap_merknad      text           null                     -- A
)Engine=InnoDB;



-- 14.4.6 Arkiv (arkiv)
--
-- NOTES:
--   R: ar_abaseid: Thomas, du hadde valgt not null unique her. Hvorfor ?
--   T: Fordi det str Unik ID som skiller... i merknaden. UNIQUE er 
--      en god ting for  forsikre seg om at innslag i databasen ikke
--      er duplikater.
--   R: Jo, men "Unik" str det overalt i spesifikasjonen, p de fleste
--      PK. Det jeg ser p, er "b"-en i O-kolonnen, som betyr at feltet skal
--      vre NOT NULL nr nremere spesifiserte betingelser er oppfylt. 
--      Ellers kan det vre NULL. 
--   T: Du har rett, og jeg er enig med deg.
--  
--   R: ar_fradato: Thomas, du hadde valgt not null her
--   T: Ja, jeg s ingen grunn til at dette feltet skulle vre tomt :)
--      Feltet kan dog godt defineres som null.
--   R: Ja, for hvis vi setter NOT NULL p dette, og en leverandr som 
--      utvikler en  Noark-4 applikasjon har valgt  ha NULL, da blir 
--      det vel konflikter nr vi skal importere data i databasen ?
--   T: Det er et godt poeng, men det er antageligvis ganske mange avvik
--      fra NOARK-system til NOARK-system. Det str eksplisitt i andre 
--      avsnitt av kapittel 14.1: ... men [det] skal ikke forsts slik
--      at utformingen av tabeller og attributter skal vre eksakt slik
--      som beskrevet. :).
drop table if exists arkiv;

create table arkiv(
    ar_arkiv        varchar(10)    not null    primary key, -- O
    ar_betegn       varchar(70)    not null,		    -- O
    ar_skaper       varchar(70)    null,		    -- O
    ar_primnok      varchar(10)    null,		    -- O1
    ar_numser       int(10)        null,		    -- O1
    ar_abaseid      int(10)        null, 		    -- O
    ar_fradato      date           null,		    -- O
    ar_tildato      date           null,		    -- O
    ar_merknad      text           null                     -- A
)Engine=InnoDB;



-- 14.4.7 Arkivdel (arkivdel)
drop table if exists arkivdel;

create table arkivdel(
    ad_arkdel       varchar(10)    not null    primary key, -- O
    ad_betegn       varchar(70)    not null,		    -- O
    ad_arkiv        varchar(10)    not null,		    -- O
    ad_periode      int(5)         null,		    -- O
    ad_astatus      varchar(2)     not null,		    -- O
    ad_primnok      varchar(10)    not null,		    -- O
    ad_spefsak      bool           not null, 		    -- /O/
    ad_spefdok      bool           not null, 		    -- /O/
    ad_lukket       bool           not null, 		    -- /O/
    ad_bsprins      text           null,		    -- O
    ad_bskode       varchar(2)     null,		    -- O
    ad_forts        varchar(10)    null,		    -- O
    ad_papir        bool           null,    		    -- O2
    ad_eldok        bool           null,    		    -- O2
    ad_numser       int(10)        null,		    -- O
    ad_primkod      varchar(70)    null, 		    -- O
    ad_seknok       varchar(10)    null,		    -- A
    ad_frisek       bool           null,		    -- A
    ad_rpgruppe     varchar(10)    null,		    -- A
    ad_fradato      date           null,		    -- O
    ad_tildato      date           null,		    -- O
    ad_lok          text           null,		    -- O
    ad_merknad      text           null,		    -- O
    ad_raputv       varchar(10)    null,		    -- A
    ad_ekspdato     date           null,		    -- O
    ad_kontrdato    date           null,		    -- O
    ad_kontrav      int(10)        null                     -- O
)Engine=InnoDB;


-- 14.4.8 Ordningsprinsipp (ordnprins)
drop table if exists ordnprins;

create table ordnprins(
    op_ordnpri      varchar(10)    not null    primary key, -- O
    op_betegn       varchar(70)    not null,		    -- O
    op_ltekst       varchar(20)    not null,		    -- O
    op_type         varchar(10)    null,    		    -- O1
    op_ovbesk       bool           not null,		    -- O
    op_klflagg      bool           not null,		    -- O
    op_siflagg      bool           not null,		    -- O
    op_evok         bool           not null,		    -- O
    op_evauto       bool           not null,		    -- O
    op_sekflagg     bool           not null,		    -- O
    op_seknok       varchar(10)    null,		    -- A
    op_fradato      date           null,		    -- O
    op_tildato      date           null,		    -- O
    op_makslen      int(2)         null,		    -- A
    op_tgkode       varchar(2)     null,		    -- A
    op_merknad      text           null                     -- A
)Engine=InnoDB;



-- 14.4.9 Ordningsverdi (ordnverdi)
drop table if exists ordnverdi;

create table ordnverdi(
    ov_ordnpri      varchar(10)    not null,                -- O
    ov_ordnver      varchar(70)    not null,		    -- O
    ov_far          varchar(70)    null,		    -- O
    ov_beskriv      text           null,		    -- O
    ov_regflagg     bool           not null,		    -- O
    ov_sekflagg     bool           not null,		    -- O
    ov_seknok       varchar(10)    null,		    -- O
    ov_arkdel       varchar(10)    null,		    -- O
    ov_bevtid       int(3)         null,		    -- A
    ov_kaskode      varchar(2)     null,		    -- A
    ov_kasregel     text           null,		    -- A
    ov_tgkode       varchar(2)     null,                    -- O
    primary key (ov_ordnpri, ov_ordnver),
    index(ov_ordnver)
)Engine=InnoDB;



-- 14.4.10 Jf. ordningsverdi (jfordnver)
drop table if exists jfordnver;

create table jfordnver(
    jo_ordnpri1     varchar(10)    not null,                -- A
    jo_ordnver1     varchar(70)    null,    		    -- A
    jo_ordnpri2     varchar(10)    null,    		    -- A
    jo_ordnver2     varchar(70)    null,    		    -- A
    jo_merknad      text           null,	            -- A
    primary key (jo_ordnpri1, jo_ordnver1, jo_ordnpri2, jo_ordnver2)
)Engine=InnoDB;



-- 14.4.11 Stikkord/emneord ordningsverdi (earkkode)
drop table if exists earkkode;

create table earkkode(
    ea_ordnpri      varchar(10)    not null,                -- A
    ea_ordnver      varchar(70)    null,    		    -- A
    ea_sordflagg    bool           null,    		    -- A
    ea_ord          varchar(70)    null,                    -- A
    primary key (ea_ordnpri, ea_ordnver, ea_ord)
)Engine=InnoDB;




-- 14.4.12 Journalenhet (journenhet)
drop table if exists journenhet;

create table journenhet(
    je_jenhet       varchar(10)    not null    primary key, -- O
    je_betegn       varchar(70)    not null,                -- O
    je_lok          text           null,                    -- A
    je_jsarkiv1     varchar(2)     null,                    -- O1
    je_jsarkiv2     varchar(2)     null,		    -- O1
    je_jssaksbh1    varchar(2)     null,		    -- O1
    je_jssaksbh2    varchar(2)     null,		    -- O1
    je_rpgruppe     varchar(10)    null,		    -- A
    je_tildato      date           null                     -- A
)Engine=InnoDB;



-- 14.4.13 Nummerserie (numserie)
drop table if exists numserie;

create table numserie(
    nu_id           int(10)        not null,                -- O
    nu_betegn       varchar(70)    null,		    -- O
    nu_aar          int(4)         null,		    -- O
    nu_seknr1       int(10)        not null,		    -- O
    nu_seknr2       int(10)        null,		    -- O
    nu_aarauto      bool           not null,                -- O
    primary key (nu_id, nu_aar)  
)Engine=InnoDB;



-- 14.4.14 Relasjonen Journalenhet - Arkivdel (jenarkdel)
drop table if exists jenarkdel;

create table jenarkdel(
    ja_jenhet       varchar(10)    not null,                -- O
    ja_arkdel       varchar(10)    not null,                -- O
    primary key (ja_jenhet, ja_arkdel)
)Engine=InnoDB;




-- 14.4.15 Arkivstatus (arstatus)
drop table if exists arstatus;
create table arstatus(
    as_status       varchar(2)     not null    primary key, -- O
    as_betegn       varchar(70)    not null,		    -- O
    as_spefsak      bool           not null, 		    -- O
    as_spefdok      bool           not null, 		    -- O
    as_lukket       bool           not null                 -- O    
)Engine=InnoDB;



-- 14.4.16 Bortsettingskode (bskode)
drop table if exists bskode;

create table bskode(
    bk_kode         varchar(2)     not null    primary key, -- O
    bk_betegn       varchar(70)    not null                 -- O
)Engine=InnoDB;



-- 14.4.17 Type ordningsprinsipp (ordnprinstype)
drop table if exists ordnprinstype;

create table ordnprinstype(
    ot_kode         varchar(10)    not null    primary key, -- O
    ot_betegn       varchar(70)    not null                 -- O
)Engine=InnoDB;




--
-- $Log$
-- Revision 1.1  2005/09/29 13:55:13  tm
-- Added all files to repository
--
-- Revision 1.7  2005/06/02 14:47:59  tm
-- OBS: Endret NOT NULL reglene til kun ågjelde for K(O)-krav _uansett
-- hva kravspesifikasjonen sier. Sjekk ut revisjonen fr denne hvis du
-- nsker tabeller med NOT NULL satt overalt ihht. kravspekk.
--
-- Revision 1.6  2005/03/16 15:20:56  tm
-- Siste endringer.
--
-- Revision 1.5  2005/03/02 10:21:13  elark
-- fixed attribute typo
--
-- Revision 1.4  2005/02/28 12:41:14  elark
-- Added italic to "krav type" where appropriate
--
-- Revision 1.3  2005/02/23 14:35:50  elark
-- Added flags
--
-- Revision 1.2  2004/12/14 12:11:43  elark
-- Feilfikset sqlfiler og rensrekv createdb
--
-- Revision 1.1  2004/08/12 14:45:26  elark
-- Fixing where its broke.
--
-- Revision 1.6  2003/06/30 14:40:35  tm
-- Fikset feil navn p 14.4.10 jfordnver
--
-- Revision 1.5  2003/06/30 14:31:36  tm
-- Diverse feilrett.
--
-- Revision 1.4  2003/06/30 12:13:19  tm
-- Rettet skrivefeil.
--
-- Revision 1.3  2003/06/30 11:48:33  tm
-- Nye versjoner av alt mulig fra Rune. Ikke gjennomgtt enn.
--
-- Revision 1.4  2003/06/25 14:17:21  tm
-- Gikk gjennom og svarte p sprsml fra Rune. Ikke sjekket for riktig
-- syntaks.
--
-- Revision 1.2  2003/06/19 14:11:17  tm
-- Opprettet en SQL-fil for hver modul. Rettet feil i Runes utkast etter
-- beste evne, og strukturerte tabellene bedre.
--
-- 
