-- -------------------------------------------------------------------
-- $Id: modul_14.5_tilgang_brukeradm_tabeller.sql 5 2005-09-29 13:55:16Z tm $
-- -------------------------------------------------------------------
-- 14.5 - Modul for tilgangsstyring og brukeradministrasjon
-- 
-- Author: Rune Runnest
--         Thomas Malt
--
-- -------------------------------------------------------------------



-- 14.5.1 Person (person)
drop table if exists person;

create table person(
    pe_id           int(10)        not null    primary key, -- O
    pe_brukerid     varchar(30)    null,		    -- A
    pe_fradato      date           null,		    -- O
    pe_tildato      date           null                     -- O
)Engine=InnoDB;



-- 14.5.2 Personnavn (pernavn)
drop table if exists pernavn;

create table pernavn(
    pn_id           int(10)        not null    primary key, -- O
    pn_peid         int(10)        not null,		    -- O
    pn_aktiv        bool           not null,		    -- O
    pn_init         varchar(10)    null,		    -- O
    pn_navn         varchar(70)    null,		    -- O
    pn_fornavn      varchar(30)    null,		    -- A
    pn_mnavn        varchar(30)    null,		    -- A
    pn_enavn        varchar(30)    null,		    -- A
    pn_fradato      date           null,		    -- O
    pn_tildato      date           null                     -- O
)Engine=InnoDB;


-- 14.5.3 Adresse til person (adrperson)
drop table if exists adrperson;

create table adrperson(
    pa_peid         int(10)     not null,                   -- U
    pa_adrid        int(10)     not null,                   -- U
    primary key (pa_peid, pa_adrid)            
)Engine=InnoDB;



-- 14.5.4 Person - Rolle (perrolle)
drop table if exists perrolle;

create table perrolle(
    pr_id           int(10)        not null    primary key, -- O
    pr_peid         int(10)        not null,		    -- O
    pr_rolleid      int(10)        null,		    -- /O/
    pr_stdrolle     bool           not null,		    -- O
    pr_tittel       varchar(30)    null,		    -- O
    pr_admid        int(10)        not  null,		    -- O
    pr_jenhet       varchar(10)    null,		    -- O
    pr_arkdel       varchar(10)    null,		    -- O
    pr_fradato      date           null,		    -- O
    pr_tildato      date           null                     -- O        
)Engine=InnoDB;



-- 14.5.5 Funger i rolle (fungrolle)
drop table if exists fungrolle;

create table fungrolle(
    fr_prid         int(10)        not null,                -- A
    fr_fungprid     int(10)        not null,                -- A
    fr_merknad      text           null,                    -- A
    primary key (fr_prid, fr_fungprid)
)Engine=InnoDB;




-- 14.5.6 Rolle (rolle)
drop table if exists rolle;

create table rolle(
    ro_rolleid      int(10)        not null    primary key, -- /O1/
    ro_navn         varchar(30)    not null,		    -- /O1/
    ro_sok          bool           not null,		    -- /O1/
    ro_sysadm       bool           not null,		    -- /O1/
    ro_arkleder     bool           not null,		    -- /O1/
    ro_leder        bool           not null,		    -- /O1/
    ro_saksbh       bool           not null,		    -- /O1/
    ro_utvsekr      bool           not null,		    -- /U1/
    ro_regutvmed    bool           not null,		    -- /U1/
    ro_drift        bool           not null,		    -- /A/
    ro_regroller    bool           not null,		    -- /O1/
    ro_aut          varchar(1)     not null,		    -- /O1/
    ro_tildelrol    varchar(1)     not null,		    -- /O1/
    ro_regadm       varchar(1)     not null,		    -- /A/
    ro_regperson    bool           not null,		    -- /A/
    ro_regark       bool           not null,		    -- /A/
    ro_regadr       bool           not null,		    -- /O1/
    ro_nysak        varchar(1)     not null,		    -- /O1/
    ro_esansv       varchar(1)     not null,		    -- /A/
    ro_eklass       varchar(1)     not null,		    -- /A/
    ro_etklass      varchar(1)     not null,		    -- /A/
    ro_esstat       varchar(1)     not null,		    -- /A/
    ro_flyttjp      varchar(1)     not null,		    -- /O1/
    ro_nyjposti     varchar(1)     not null,		    -- /O1/
    ro_nyjposte     varchar(1)     not null,		    -- /O1/
    ro_esbh         varchar(1)     not null,		    -- /A/
    ro_avskriv      varchar(1)     not null,		    -- /A/
    ro_ekspdok      varchar(1)     not null,		    -- /A/
    ro_esdel        varchar(1)     not null,		    -- /A/
    ro_efrist       varchar(1)     not null,		    -- /A/
    ro_etilg        varchar(1)     not null,		    -- /O1/
    ro_tedok        varchar(1)     not null,		    -- /O1/
    ro_arkkon       varchar(1)     not null,		    -- /O1/
    ro_rmerkn       varchar(1)     not null,		    -- /O1/
    ro_arklogg      varchar(1)     not null                 -- /A/     
)Engine=InnoDB;




-- 14.5.7 Tilgang til informasjon (tginfo)
drop table if exists tginfo;

create table tginfo(
    tj_peid         int(10)        not null,                -- O1
    tj_jenhet       varchar(10)        null,		    -- O1
    tj_admid        int(10)        null,    		    -- O1
    tj_autav        int(10)        null,    		    -- O1
    tj_fradato      date           null,    		    -- O1
    tj_tildato      date           null,		    -- O1
    tj_autoppav     int(10)        null,                    -- O1
    primary key (tj_peid, tj_jenhet, tj_admid) 
)Engine=InnoDB;



-- 14.5.8 Tilgangskode (tgkode)
drop table if exists tgkode;

create table tgkode(
    tk_tgkode       varchar(2)     not null    primary key, -- O
    tk_betegn       varchar(70)    not null,		    -- O
    tk_serie        int(4)         null,		    -- A
    tk_rang         int(4)         null,		    -- A
    tk_fradato      date           null,		    -- A
    tk_tildato      date           null,		    -- A
    tk_epostniv     int(1)         null                     -- E1
)Engine=InnoDB;



-- 14.5.9 Hjemmel for tilgangskode (tghjemmel)
drop table if exists tghjemmel;

create table tghjemmel(
    th_tgkode       varchar(2)     not null,                -- O
    th_uoff         varchar(70)    not null,		    -- O
    th_agkode       varchar(2)     null,		    -- O
    th_agaar        int(2)         null,		    -- O
    th_agdager      int(3)         null,		    -- O
    th_anvend       text           null,                    -- O
    primary key (th_tgkode, th_uoff)
)Engine=InnoDB;



-- 14.5.10 Klarering for tilgangskode (perklarer)
drop table if exists perklarer;

create table perklarer(
    kt_peid         int(10)        not null,                -- O
    kt_tgkode       varchar(2)     not null,		    -- O
    kt_authele      bool           not null,		    -- O
    kt_klav         int(10)        not null,                -- O
    kt_fradato      date           null,    		    -- A
    kt_klopphav     int(10)        null, 		    -- A
    kt_tildato      date           null,		    -- A
    kt_merknad      text           null,                    -- A 
    primary key (kt_peid, kt_tgkode)
)Engine=InnoDB;



-- 14.5.11 Autorisasjon innen administrativ enhet (pertgkode)
drop table if exists pertgkode;

create table pertgkode(
    pt_peid         int(10)        not null,                -- O1
    pt_tgkode       varchar(2)     null,		    -- O1
    pt_admid        int(10)        null,    		    -- O1
    pt_autav        int(10)        null,    		    -- O1
    pt_fradato      date           null,    		    -- O1
    pt_tildato      date           null,		    -- O1
    pt_autoppav     int(10)        null,                    -- O1
    primary key (pt_peid, pt_tgkode, pt_admid)
)Engine=InnoDB;



-- 14.5.12 Tilgangsgruppe (tggruppe)
drop table if exists tggruppe;

create table tggruppe(
    tg_gruppeid     int(10)        not null    primary key, -- O1
    tg_gruppenavn   varchar(70)    null,    		    -- O1
    tg_generell     bool           null,    		    -- O1
    tg_opprav       int(10)        null,     		    -- O1
    tg_fradato      date           null,    		    -- O1
    tg_tildato      date           null                     -- O1      
)Engine=InnoDB;



-- 14.5.13 Medlemskap i tilgangsgruppe (tgmedlem)

--   R: primary key: det m vre noe feil her, pg_perrolid m vre 
--      NOT NULL hvis dette feltet skal inng i primrnkkelen. 
--      Hvorfor inngr ikke pg_peid i PK ?
--   T: Det ser ut som en feil, hr med Jon Atle. For meg ser det ut
--      som primrnkkelen egentlig burde vre (pg_peid, pg_gruppeid).
--   R: Iflg. Jon Atle skal PK vre pg_peid + pg_gruppeid. 
drop table if exists tgmedlem;

create table tgmedlem(
    pg_peid         int(10)        not null,                -- O1
    pg_gruppeid     int(10)        null,    		    -- O1
    pg_perrolid     int(10)        null,		    -- O1
    pg_medkod       int(4)         null,		    -- O1
    pg_innmav       int(10)        null,    		    -- O1
    pg_fradato      date           null,		    -- O1
    pg_tildato      date           null,		    -- O1
    pg_utmav        int(10)        null,                    -- O1       
    primary key (pg_peid, pg_gruppeid) 
)Engine=InnoDB;



--
-- $Log$
-- Revision 1.1  2005/09/29 13:55:13  tm
-- Added all files to repository
--
-- Revision 1.8  2005/06/03 15:12:12  tm
-- Siste endringer i arkN4. referansesjekker skal virke nå
--
-- Revision 1.7  2005/06/02 14:47:59  tm
-- OBS: Endret NOT NULL reglene til kun ågjelde for K(O)-krav _uansett
-- hva kravspesifikasjonen sier. Sjekk ut revisjonen fr denne hvis du
-- nsker tabeller med NOT NULL satt overalt ihht. kravspekk.
--
-- Revision 1.6  2005/03/01 14:49:02  elark
-- *** empty log message ***
--
-- Revision 1.5  2005/02/28 12:41:14  elark
-- Added italic to "krav type" where appropriate
--
-- Revision 1.4  2005/02/23 14:35:50  elark
-- Added flags
--
-- Revision 1.3  2004/12/20 11:52:25  elark
-- fikset skrivefeil
--
-- Revision 1.2  2004/12/17 09:41:45  elark
-- Hjelpescript + feilfix  i databasedefinisjon.
--
-- Revision 1.1  2004/08/12 14:45:26  elark
-- Fixing where its broke.
--
-- Revision 1.2  2003/06/30 15:43:45  tm
-- Fikset endel skrivefeil.
--
-- Revision 1.1  2003/06/30 11:49:46  tm
-- Nye versjoner av komplett NOARK database fra Rune ikke gjennomgtt enn.
--
-- Revision 1.3  2003/06/26 11:54:28  tm
-- Gjennomgang av de siste tabellene med svar p sprsml. Syntax ikke grundig
-- sjekket.
--
-- Revision 1.2  2003/06/19 14:12:25  tm
-- Manglet en fil.
-- 
--
