#!/usr/bin/perl
#---------------------------------------------------------------------
# $Id: 002.config.t 583 2011-06-01 12:00:13Z tm $
#---------------------------------------------------------------------
# Automatic test of Noark::Config;

use strict;
use warnings;

use lib qw(./lib);

use Data::Dumper;

use Test::Differences;
use Test::More tests => 20;

BEGIN {
    use_ok("Noark::Config", qw($config $tables $dtds parse_config));
};

# Verify parsing of default configuration file
for my $k (qw(
              ADD_POSTNR
              CREATEDB_NAME
              DATADIR
              DB_HOST 
              DB_NAME
              DB_PASS 
              DB_USER
              DOCDIR
              IMPORTDIR
              OUT_DIR 
              REPORTDIR
              REPORT_FORMAT
              REPORT_MAX_ERRORS 
              REPORT_NAME
              XMLDIR 
            )) {
    ok(defined $config->{$k}, "Check key '".$k."' exists in config");
}

can_ok("Noark::Config", qw(parse_config get_file_str __get_config_dir));

eq_or_diff($tables, test_get_tables(),
           "testing getting the \$tables hash.");
eq_or_diff($dtds, test_get_dtds(),
           "testing getting the \$dtds hash");
eq_or_diff(parse_config("t/test.conf"), test_get_testconf(),
           "testing parse_config()");

sub test_get_testconf {
    my $VAR1 = {
                'NAME' => 'Thomas Malt',
                'SUBARU' => 'impresa',
                'AGE' => '33',
                'LIST' => 'dette, er en, komma, separert, liste'
               };

    return $VAR1;

}

sub test_get_dtds {
    my $VAR1 = {
          'EOPRESEDENS.TAB' => 'EOPRES.DTD',
          'JOURNSTATUS.TAB' => 'JOURNSTA.DTD',
          'LFPRESEDENS.TAB' => 'LFPRES.DTD',
          'PERTGKODE.TAB' => 'PERTGKOD.DTD',
          'UTVBEHSTAT.TAB' => 'UTVBEHST.DTD',
          'SAKSTYPE.TAB' => 'SAKTYPE.DTD',
          'ENHETSTYPE.TAB' => 'ENHTYPE.DTD',
          'DOKKATEGORI.TAB' => 'DOKKAT.DTD',
          'TLKODE.TAB' => 'TLKODE.DTD',
          'TGHJEMMEL.TAB' => 'TGHJEM.DTD',
          'AVGRADKODE.TAB' => 'AVGRKODE.DTD',
          'MERKNAD.TAB' => 'MERKNAD.DTD',
          'ADRTYPE.TAB' => 'ADRTYPE.DTD',
          'EODOKUMENT.TAB' => 'EODOK.DTD',
          'BSKODE.TAB' => 'BSKODE.DTD',
          'FSTATUS.TAB' => 'FSTATUS.DTD',
          'SAKSTATUS.TAB' => 'SAKSTAT.DTD',
          'EKSTSAKREF.TAB' => 'ESAKREF.DTD',
          'JFSAK.TAB' => 'JFSAK.DTD',
          'JOURNAL' => 'JOURNAL.DTD',
          'ADRESSEKP.TAB' => 'ADRESSEK.DTD',
          'OFFJOURNAL' => 'OFFJOURN.DTD',
          'VARIANTFORMAT.TAB' => 'VARFORM.DTD',
          'PERSON.TAB' => 'PERSON.DTD',
          'FUNGROLLE.TAB' => 'FUNGROLL.DTD',
          'ARKIVPERIODE.TAB' => 'ARKIVPER.DTD',
          'MEDLADRGR.TAB' => 'MEDADRGR.DTD',
          'ORDNPRINS.TAB' => 'ORDNPRI.DTD',
          'PERROLLE.TAB' => 'PERROLLE.DTD',
          'UTVALGSAK.TAB' => 'UTVSAK.DTD',
          'UTVBEHANDLING.TAB' => 'UTVBEH.DTD',
          'PRESEDENS.TAB' => 'PRES.DTD',
          'ORDNPRINSTYPE.TAB' => 'OPRITYP.DTD',
          'TILLEGGSINFO.TAB' => 'TILLEGG.DTD',
          'UTVMOTE.TAB' => 'UTVMOTE.DTD',
          'NOARKDOKTYPE.TAB' => 'DOKTYPE.DTD',
          'LAGRENHET.TAB' => 'LAGRENH.DTD',
          'UTVMOTEDOK.TAB' => 'UTVMDOK.DTD',
          'UTVALG.TAB' => 'UTVALG.DTD',
          'AVSKRMAATE.TAB' => 'AVSKRM.DTD',
          'TGGRUPPE.TAB' => 'TGGRP.DTD',
          'UTVSAKTYP.TAB' => 'UTVSAKTY.DTD',
          'AVSMOT.TAB' => 'AVSMOT.DTD',
          'MOTEDOKLINK.TAB' => 'MOTDOKL.DTD',
          'KASSKODE.TAB' => 'KASSKODE.DTD',
          'DOKSTATUS.TAB' => 'DOKSTAT.DTD',
          'ARSTATUS.TAB' => 'ARSTATUS.DTD',
          'DOKBESKRIV.TAB' => 'DOKBESK.DTD',
          'KLASSERING.TAB' => 'KLASS.DTD',
          'JFORDNVER.TAB' => 'JFORNVER.DTD',
          'INFOTYPE.TAB' => 'INFOTYPE.DTD',
          'DOKVERSJON.TAB' => 'DOKVERS.DTD',
          'PERNAVN.TAB' => 'PERNAVN.DTD',
          'EOHENV.TAB' => 'EOHENV.DTD',
          'SAKDOKOVERSIKT' => 'SAKDOK.DTD',
          'JENARKDEL.TAB' => 'JENARKD.DTD',
          'DIGISIGN.TAB' => 'DIGISIGN.DTD',
          'PERKLARER.TAB' => 'PERKLAR.DTD',
          'NUMSERIE.TAB' => 'NUMSERIE.DTD',
          'STATUSMDOK.TAB' => 'STATMDOK.DTD',
          'ORDNVERDI.TAB' => 'ORDNVERD.DTD',
          'ADMINDEL.TAB' => 'ADMINDEL.DTD',
          'FORSMAATE.TAB' => 'FORSMATE.DTD',
          'PRESHENV.TAB' => 'PRESHENV.DTD',
          'POSTNR.TAB' => 'POSTNR.DTD',
          'FRAMMOTE.TAB' => 'FRAMMOTE.DTD',
          'NOARK.IH' => 'NOARKIH.DTD',
          'UTVSAKSKART.TAB' => 'UTVSAKKA.DTD',
          'LFKODER.TAB' => 'LFKODER.DTD',
          'BEHAVHENG.TAB' => 'BEHAVH.DTD',
          'EARKKODE.TAB' => 'EARKKODE.DTD',
          'UTVMEDLFUNK.TAB' => 'UTVMEDLF.DTD',
          'TGMEDLEM.TAB' => 'TGMEDLEM.DTD',
          'EMNEORD.TAB' => 'EMNEORD.DTD',
          'JOURNENHET.TAB' => 'JOURNENH.DTD',
          'NOARKSAK.TAB' => 'NOARKSAK.DTD',
          'ADRADMENH.TAB' => 'ADRADMEN.DTD',
          'UTVBEHDOK.TAB' => 'UTVBEHDO.DTD',
          'DIGISERT.TAB' => 'DIGISERT.DTD',
          'ALIASADMENH.TAB' => 'ALIASADM.DTD',
          'ROLLE.TAB' => 'ROLLE.DTD',
          'JOURNPOST.TAB' => 'JOURNPST.DTD',
          'ADRPERSON.TAB' => 'ADRPERS.DTD',
          'UTVTYPE.TAB' => 'UTVTYPE.DTD',
          'LAGRFORMAT.TAB' => 'LAGRFORM.DTD',
          'KPFORMAT.TAB' => 'KPFORMAT.DTD',
          'KPAUTORIS.TAB' => 'KPAUT.DTD',
          'ARKIV.TAB' => 'ARKIV.DTD',
          'SAKSPART.TAB' => 'SAKPART.DTD',
          'STDVERDI.TAB' => 'STDVERDI.DTD',
          'POLSAKSGANG.TAB' => 'POLSAKG.DTD',
          'DOKTILKN.TAB' => 'DOKTILKN.DTD',
          'UTVMEDLEM.TAB' => 'UTVMEDL.DTD',
          'UTDOKTYP.TAB' => 'UTDOKTYP.DTD',
          'EOHIERARKI.TAB' => 'EOHIER.DTD',
          'NOARK.H' => 'NOARKH.DTD',
          'TGINFO.TAB' => 'TGINFO.DTD',
          'DOKLINK.TAB' => 'DOKLINK.DTD',
          'TGKODE.TAB' => 'TGKODE.DTD',
          'ARKIVDEL.TAB' => 'ARKIVDEL.DTD'
        };

    return $VAR1;
}

sub test_get_tables {
    my $VAR1 = { 
                'MS.BETEGN' => 'ms_betegn', 
                'ML.RNR' => 'ml_rnr', 
                'LF.ARKIV' => 'lf_arkiv', 
                'ED.SORDFLAGG' => 'ed_sordflagg', 
                'AK.KORTNAVN' => 'ak_kortnavn', 
                'AI.FORKDN' => 'ai_forkdn', 
                'UM.MEDLEM' => 'um_medlem',
'ME.TEKST' => 'me_tekst',
'AM.ADMID' => 'am_admid',
'ME.REFDOKID' => 'me_refdokid',
'AS.LUKKET' => 'as_lukket',
'RO.SAKSBH' => 'ro_saksbh',
'PN.INIT' => 'pn_init',
'SV.TGJP1' => 'sv_tgjp1',
'BSKODE.TAB' => 'bskode',
'JP.UTLTIL' => 'jp_utltil',
'FSTATUS.TAB' => 'fstatus',
'AP.MERKNAD' => 'ap_merknad',
'JS.DOKKONTR' => 'js_dokkontr',
'EKSTSAKREF.TAB' => 'ekstsakref',
'MD.ADMID' => 'md_admid',
'OP.MERKNAD' => 'op_merknad',
'IT.MERKNAD' => 'it_merknad',
'JP.U1' => 'jp_u1',
'LF.FILTYPE' => 'lf_filtype',
'PR.FRADATO' => 'pr_fradato',
'PR.ARKDEL' => 'pr_arkdel',
'SK.SAKSTYPE' => 'sk_sakstype',
'JE.JSSAKSBH1' => 'je_jssaksbh1',
'AM.U1' => 'am_u1',
'PT.PEID' => 'pt_peid',
'ME.REGKL' => 'me_regkl',
'DK.BETEGN' => 'dk_betegn',
'UTVMOTE.TAB' => 'utvmote',
'TI.REGKL' => 'ti_regkl',
'LAGRENHET.TAB' => 'lagrenhet',
'US.UOFF' => 'us_uoff',
'AP.FRADATO' => 'ap_fradato',
'TH.UOFF' => 'th_uoff',
'JS.STATUS' => 'js_status',
'BA.UBID1' => 'ba_ubid1',
'MO.ROM' => 'mo_rom',
'DB.KATEGORI' => 'db_kategori',
'EA.ORD' => 'ea_ord',
'PS.TGGRUPPE' => 'ps_tggruppe',
'KASSKODE.TAB' => 'kasskode',
'AP.TILDATO' => 'ap_tildato',
'KLASSERING.TAB' => 'klassering',
'UT.ID' => 'ut_id',
'SA.OPSAKSDEL' => 'sa_opsaksdel',
'INFOTYPE.TAB' => 'infotype',
'NU.SEKNR2' => 'nu_seknr2',
'PN.ID' => 'pn_id',
'TI.ID' => 'ti_id',
'OV.REGFLAGG' => 'ov_regflagg',
'KA.AUTAV' => 'ka_autav',
'PS.LOK' => 'ps_lok',
'RO.TEDOK' => 'ro_tedok',
'KK.BETEGN' => 'kk_betegn',
'FR.MERKNAD' => 'fr_merknad',
'UB.RFOLGE' => 'ub_rfolge',
'DB.UOFF' => 'db_uoff',
'SV.BFRIST2' => 'sv_bfrist2',
'PL.PARAGRAF' => 'pl_paragraf',
'JP.FORFDATO' => 'jp_forfdato',
'UM.VARIGHET' => 'um_varighet',
'AM.AVSKAV' => 'am_avskav',
'AD.SEKNOK' => 'ad_seknok',
'PERKLARER.TAB' => 'perklarer',
'SP.POSTSTED' => 'sp_poststed',
'AD.ARKDEL' => 'ad_arkdel',
'PS.UOFF' => 'ps_uoff',
'JF.TPSID' => 'jf_tpsid',
'ADMINDEL.TAB' => 'admindel',
'BS.STATUS' => 'bs_status',
'SA.STATUS' => 'sa_status',
'MD.DOKTYPE' => 'md_doktype',
'VE.FILREF' => 've_filref',
'UK.BETEGN' => 'uk_betegn',
'TGMEDLEM.TAB' => 'tgmedlem',
'AD.BETEGN' => 'ad_betegn',
'ML.TKDATO' => 'ml_tkdato',
'AM.POSTSTED' => 'am_poststed',
'TI.TGGRUPPE' => 'ti_tggruppe',
'FU.VARAFOR' => 'fu_varafor',
'JP.PAPIR' => 'jp_papir',
'AR.MERKNAD' => 'ar_merknad',
'ER.ASNR' => 'er_asnr',
'KT.TILDATO' => 'kt_tildato',
'ROLLE.TAB' => 'rolle',
'ME.OPPBEDATO' => 'me_oppbedato',
'JOURNPOST.TAB' => 'journpost',
'AM.AVSKDATO' => 'am_avskdato',
'MD.U1' => 'md_u1',
'PT.TILDATO' => 'pt_tildato',
'AM.BESVAR' => 'am_besvar',
'UT.ADRID' => 'ut_adrid',
'RO.ESBH' => 'ro_esbh',
'SA.FRARKDEL' => 'sa_frarkdel',
'TGINFO.TAB' => 'tginfo',
'DB.TITTEL' => 'db_tittel',
'AS.SPEFSAK' => 'as_spefsak',
'DB.TGKODE' => 'db_tgkode',
'RO.REGROLLER' => 'ro_regroller',
'KF.FORMAT' => 'kf_format',
'UB.USEKNR' => 'ub_useknr',
'RO.ESANSV' => 'ro_esansv',
'AD.RAPUTV' => 'ad_raputv',
'PERTGKODE.TAB' => 'pertgkode',
'SG.ID' => 'sg_id',
'UM.FRADATO' => 'um_fradato',
'SA.UOFF' => 'sa_uoff',
'JS.BETEGN' => 'js_betegn',
'FM.BETEGN' => 'fm_betegn',
'AD.EKSPDATO' => 'ad_ekspdato',
'RO.ESSTAT' => 'ro_esstat',
'AL.MERKNAD' => 'al_merknad',
'SK.SORT' => 'sk_sort',
'RO.NAVN' => 'ro_navn',
'TGHJEMMEL.TAB' => 'tghjemmel',
'VE.VERSJON' => 've_versjon',
'AM.FRIST' => 'am_frist',
'DI.DOKID' => 'di_dokid',
'RO.REGADR' => 'ro_regadr',
'OV.ORDNVER' => 'ov_ordnver',
'PR.STDROLLE' => 'pr_stdrolle',
'ME.JPID' => 'me_jpid',
'PT.ADMID' => 'pt_admid',
'OV.SEKNOK' => 'ov_seknok',
'ES.EMNEORD2' => 'es_emneord2',
'JFSAK.TAB' => 'jfsak',
'PG.UTMAV' => 'pg_utmav',
'SE.VERAV' => 'se_verav',
'AD.SPEFDOK' => 'ad_spefdok',
'EH.EMNEORD1' => 'eh_emneord1',
'KT.KLOPPHAV' => 'kt_klopphav',
'UB.UTSAKID' => 'ub_utsakid',
'SG.MERKNAD' => 'sg_merknad',
'PL.MERKNAD' => 'pl_merknad',
'TK.FRADATO' => 'tk_fradato',
'MS.STATUS' => 'ms_status',
'RO.FLYTTJP' => 'ro_flyttjp',
'AK.UTLAND' => 'ak_utland',
'OV.FAR' => 'ov_far',
'US.JPID' => 'us_jpid',
'MD.UTVID' => 'md_utvid',
'PERROLLE.TAB' => 'perrolle',
'UTVALGSAK.TAB' => 'utvalgsak',
'JP.TGKODE' => 'jp_tgkode',
'OP.FRADATO' => 'op_fradato',
'EO.EMNEORD' => 'eo_emneord',
'PT.FRADATO' => 'pt_fradato',
'MD.KASSDATO' => 'md_kassdato',
'JS.ANSVAR' => 'js_ansvar', 
                 'OV.BESKR' => 'ov_beskriv', 
                 'DI.ARKSIGN' => 'di_arksign',
'UT.ARKKODE' => 'ut_arkkode',
'UTVALG.TAB' => 'utvalg',
'AD.BSPRINS' => 'ad_bsprins',
'VE.ARKMERK' => 've_arkmerk',
'DL.DOKID' => 'dl_dokid',
'UB.BEHSTATUS' => 'ub_behstatus',
'MK.BETEGN' => 'mk_betegn',
'PG.FRADATO' => 'pg_fradato',
'AI.RPGRUPPE' => 'ai_rpgruppe',
'TJ.ADMID' => 'tj_admid',
'SK.DOKDATO' => 'sk_dokdato',
'JP.U2' => 'jp_u2',
'PE.ID' => 'pe_id',
'UK.KODE' => 'uk_kode',
'DU.MOTEDOK' => 'du_motedok',
'JFORDNVER.TAB' => 'jfordnver',
'JA.ARKDEL' => 'ja_arkdel',
'JP.TGGRUPPE' => 'jp_tggruppe',
'ET.BETEGN' => 'et_betegn',
'PG.TILDATO' => 'pg_tildato',
'SV.TILGBEG' => 'sv_tilgbeg',
'AK.NAVN' => 'ak_navn',
'US.UTVID' => 'us_utvid',
'ML.DOKID' => 'ml_dokid',
'MK.MEDLEM' => 'mk_medlem',
'DI.SIGNATUR' => 'di_signatur',
'ML.TKAV' => 'ml_tkav',
'JP.EKSPDATO' => 'jp_ekspdato',
'SP.KONTAKT' => 'sp_kontakt',
'RO.UTVSEKR' => 'ro_utvsekr',
'UM.PNID' => 'um_pnid',
'JO.ORDNPRI1' => 'jo_ordnpri1',
'AG.BETEGN' => 'ag_betegn',
'AK.BASEID' => 'ak_baseid',
'SV.EKSTDOKTG' => 'sv_ekstdoktg',
'DB.AGDATO' => 'db_agdato',
'ME.TGGRUPPE' => 'me_tggruppe',
'PN.NAVN' => 'pn_navn',
'IT.TGKODE' => 'it_tgkode',
'PL.LOVFORSK' => 'pl_lovforsk',
'DU.KODE' => 'du_kode',
'BK.KODE' => 'bk_kode',
'AK.POSTNR' => 'ak_postnr',
'SE.FRADATO' => 'se_fradato',
'PH.TOVEIS' => 'ph_toveis',
'RO.NYJPOSTI' => 'ro_nyjposti',
'LAGRFORMAT.TAB' => 'lagrformat',
'KA.FRADATO' => 'ka_fradato',
'POLSAKSGANG.TAB' => 'polsaksgang',
'ML.TYPE' => 'ml_type',
'EOHIERARKI.TAB' => 'eohierarki',
'RO.REGARK' => 'ro_regark',
'JP.SAKSDEL' => 'jp_saksdel',
'DI.FORSIGN' => 'di_forsign',
'KL.ORDNPRI' => 'kl_ordnpri',
'ET.LTEKST' => 'et_ltekst',
'SS.BETEGN' => 'ss_betegn',
'ME.VARIANT' => 'me_variant',
'TL.KODE' => 'tl_kode',
'OT.KODE' => 'ot_kode',
'DB.TGGRUPPE' => 'db_tggruppe',
'BD.JPID' => 'bd_jpid',
'SA.ANTJP' => 'sa_antjp',
'MO.START' => 'mo_start',
'DB.PAPIR' => 'db_papir',
'SK.NUMFORM' => 'sk_numform',
'SP.MERKNAD' => 'sp_merknad',
'AK.TILDATO' => 'ak_tildato',
'JP.INNHOLD' => 'jp_innhold',
'SV.BEVER' => 'sv_bever',
'RO.DRIFT' => 'ro_drift',
'US.SAMMENR' => 'us_sammenr',
'PE.BRUKERID' => 'pe_brukerid',
'EH.EMNEORD2' => 'eh_emneord2',
'FU.MOID' => 'fu_moid',
'ST.UTVSAKTYPE' => 'st_utvsaktype',
'SE.EPOST' => 'se_epost',
'AD.FRADATO' => 'ad_fradato',
'ME.REGAV' => 'me_regav',
'OP.SIFLAGG' => 'op_siflagg',
'SG.LUKKET' => 'sg_lukket',
'AD.BSKODE' => 'ad_bskode',
'MD.MOID' => 'md_moid',
'AM.NAVN' => 'am_navn',
'PS.FORELDET' => 'ps_foreldet',
'AM.EPOSTADR' => 'am_epostadr',
'UT.SAMMENR' => 'ut_sammenr',
'AD.RPGRUPPE' => 'ad_rpgruppe',
'AI.FRADATO' => 'ai_fradato',
'DB.UTARBAV' => 'db_utarbav',
'UM.REPRES' => 'um_repres',
'UT.ETABLERT' => 'ut_etablert',
'ST.MERKNAD' => 'st_merknad',
'UT.NAVN' => 'ut_navn',
'ND.BETEGN' => 'nd_betegn',
'TH.ANVEND' => 'th_anvend',
'RO.TILDELROL' => 'ro_tildelrol',
'DS.STATUS' => 'ds_status',
'ND.OPPF' => 'nd_oppf',
'AL.ADMIDTIL' => 'al_admidtil',
'PT.AUTAV' => 'pt_autav',
'DOKSTATUS.TAB' => 'dokstatus',
'TI.PVGAV' => 'ti_pvgav',
'BS.SROT1' => 'bs_srot1',
'JP.DOKDATO' => 'jp_dokdato',
'PS.TGKODE' => 'ps_tgkode',
'SP.KORTNAVN' => 'sp_kortnavn',
'PS.TITTEL' => 'ps_tittel',
'DOKVERSJON.TAB' => 'dokversjon',
'PERNAVN.TAB' => 'pernavn',
'RO.AUT' => 'ro_aut',
'UB.AAR' => 'ub_aar',
'UM.SORT' => 'um_sort',
'ND.EKSTMOT' => 'nd_ekstmot',
'UM.UTVID' => 'um_utvid',
'MD.ID' => 'md_id',
'JF.MERKNAD' => 'jf_merknad',
'UTVSAKSKART.TAB' => 'utvsakskart',
'US.SAKSTYPE' => 'us_sakstype',
'PN.ENAVN' => 'pn_enavn',
'TK.EPOSTNIV' => 'tk_epostniv',
'ME.ID' => 'me_id',
'SA.ID' => 'sa_id',
'JS.FORLEDER' => 'js_forleder',
'SK.OVSKR' => 'sk_ovskr',
'SG.STARTDATO' => 'sg_startdato',
'AA.ADRID' => 'aa_adrid',
'TI.REGDATO' => 'ti_regdato',
'ADRADMENH.TAB' => 'adradmenh',
'AK.OPDGRUPPE' => 'ak_opdgruppe',
'SK.ARKSNR' => 'sk_arksnr',
'DU.NDOKTYPE' => 'du_ndoktype',
'SU.BETEGN' => 'su_betegn',
'MO.MERKNAD' => 'mo_merknad',
'JP.SEKNR' => 'jp_seknr',
'OP.ORDNPRI' => 'op_ordnpri',
'AI.ADMBET' => 'ai_admbet',
'AD.KONTRDATO' => 'ad_kontrdato',
'PS.ADMID' => 'ps_admid',
'OP.OVBESK' => 'op_ovbesk',
'EA.SORDFLAGG' => 'ea_sordflagg',
'JO.ORDNPRI2' => 'jo_ordnpri2',
'DI.SIGVERDATO' => 'di_sigverdato',
'UTDOKTYP.TAB' => 'utdoktyp',
'KA.TILDATO' => 'ka_tildato',
'OP.SEKNOK' => 'op_seknok',
'DOKTILKN.TAB' => 'doktilkn',
'DT.BETEGN' => 'dt_betegn',
'RO.ARKLOGG' => 'ro_arklogg',
'NU.BETEGN' => 'nu_betegn',
'OT.BETEGN' => 'ot_betegn',
'VF.KODE' => 'vf_kode',
'OP.TILDATO' => 'op_tildato',
'OP.LTEKST' => 'op_ltekst',
'MO.FORTS' => 'mo_forts',
'VF.BETEGN' => 'vf_betegn',
'AI.TYPE' => 'ai_type',
'ER.ADMBET' => 'er_admbet',
'AD.PERIODE' => 'ad_periode',
'SE.SERT' => 'se_sert',
'JP.UTLDATO' => 'jp_utldato',
'US.LUKKET' => 'us_lukket',
'FR.PRID' => 'fr_prid',
'KT.AUTHELE' => 'kt_authele',
'DI.SIGVERAV' => 'di_sigverav',
'BS.SAKSKART' => 'bs_sakskart',
'UB.SBHID' => 'ub_sbhid',
'AVGRADKODE.TAB' => 'avgradkode',
'JP.SAID' => 'jp_said',
'AM.POSTNR' => 'am_postnr',
'PE.FRADATO' => 'pe_fradato',
'EODOKUMENT.TAB' => 'eodokument',
'PS.TYPE' => 'ps_type',
'AD.FRISEK' => 'ad_frisek',
'VE.TGKODE' => 've_tgkode',
'ADRESSEKP.TAB' => 'adressekp',
'JP.JAAR' => 'jp_jaar',
'MD.PAPIRDOK' => 'md_papirdok',
'VARIANTFORMAT.TAB' => 'variantformat',
'PS.SAID' => 'ps_said',
'MK.TALE' => 'mk_tale',
'KT.PEID' => 'kt_peid',
'KT.KLAV' => 'kt_klav',
'AK.POSTADR' => 'ak_postadr',
'ST.KLAGEADG' => 'st_klageadg',
'DT.JOURNAL' => 'dt_journal',
'SG.SAID' => 'sg_said',
'TI.REFDOKID' => 'ti_refdokid',
'OP.BETEGN' => 'op_betegn',
'ED.ORD' => 'ed_ord',
'ORDNPRINSTYPE.TAB' => 'ordnprinstype',
'NOARKDOKTYPE.TAB' => 'noarkdoktype',
'DI.VERSJON' => 'di_versjon',
'AT.KODE' => 'at_kode',
'DU.AUTOJOUR' => 'du_autojour',
'PS.TEKST' => 'ps_tekst',
'JE.RPGRUPPE' => 'je_rpgruppe',
'TGGRUPPE.TAB' => 'tggruppe',
'BD.STATUS' => 'bd_status',
'TK.SERIE' => 'tk_serie',
'RO.LEDER' => 'ro_leder',
'MD.UOFF' => 'md_uoff',
'AD.KONTRAV' => 'ad_kontrav',
'ME.DOKID' => 'me_dokid',
'AVSMOT.TAB' => 'avsmot',
'ES.EMNEORD1' => 'es_emneord1',
'AK.MOBIL' => 'ak_mobil',
'AD.ASTATUS' => 'ad_astatus',
'DOKBESKRIV.TAB' => 'dokbeskriv',
'TG.GENERELL' => 'tg_generell',
'UB.ADMID' => 'ub_admid',
'AS.STATUS' => 'as_status',
'SV.SKTADM' => 'sv_sktadm',
'AD.PRIMNOK' => 'ad_primnok',
'MD.REGDATO' => 'md_regdato',
'FR.FUNGPRID' => 'fr_fungprid',
'AR.ARKIV' => 'ar_arkiv',
'AM.GRUPPEMOT' => 'am_gruppemot',
'DIGISIGN.TAB' => 'digisign',
'UM.MERKNAD' => 'um_merknad',
'TG.TILDATO' => 'tg_tildato', 
                 'TG.GRUPPNAVN' => 'tg_gruppenavn', 
                 'PRESHENV.TAB' => 'preshenv',
'SV.BFRIST1' => 'sv_bfrist1',
'ER.AJPID' => 'er_ajpid',
'NU.SEKNR1' => 'nu_seknr1',
'BEHAVHENG.TAB' => 'behavheng',
'IT.KODE' => 'it_kode',
'PS.EKSTERN' => 'ps_ekstern',
'PR.ROLLEID' => 'pr_rolleid',
'SA.DATO' => 'sa_dato',
'EMNEORD.TAB' => 'emneord',
'JOURNENHET.TAB' => 'journenhet',
'KA.DATE' => 'ka_date',
'KL.SORT' => 'kl_sort',
'AT.BETEGN' => 'at_betegn',
'KT.FRADATO' => 'kt_fradato',
'RO.AVSKRIV' => 'ro_avskriv',
'KL.SAID' => 'kl_said',
'SA.PROSJEKT' => 'sa_prosjekt',
'SP.TLF' => 'sp_tlf',
'DL.RNR' => 'dl_rnr',
'OP.SEKFLAGG' => 'op_sekflagg',
'AD.ELDOK' => 'ad_eldok',
'JE.BETEGN' => 'je_betegn',
'PE.TILDATO' => 'pe_tildato',
'SV.ARKFAVSL' => 'sv_arkfavsl',
'AA.ADMID' => 'aa_admid',
'KF.ADRID' => 'kf_adrid',
'PR.TILDATO' => 'pr_tildato',
'SS.MIDLERTIDIG' => 'ss_midlertidig',
'UTVMEDLEM.TAB' => 'utvmedlem',
'RO.SYSADM' => 'ro_sysadm',
'MO.LUKKET' => 'mo_lukket',
'SS.LUKKET' => 'ss_lukket',
'DL.TKDATO' => 'dl_tkdato',
'UT.OPPNDATO' => 'ut_oppndato',
'PO.POSTSTED' => 'po_poststed',
'SA.TGGRUPPE' => 'sa_tggruppe',
'TI.OPPBEDATO' => 'ti_oppbedato',
'TH.AGKODE' => 'th_agkode',
'DOKLINK.TAB' => 'doklink',
'ED.DOKID' => 'ed_dokid',
'LFPRESEDENS.TAB' => 'lfpresedens',
'SA.SISTEJP' => 'sa_sistejp',
'UB.ID' => 'ub_id',
'KT.MERKNAD' => 'kt_merknad',
'LA.BESKRIV' => 'la_beskriv',
'KA.ADRID' => 'ka_adrid',
'SK.TITTEL' => 'sk_tittel',
'SAKSTYPE.TAB' => 'sakstype',
'BD.DOKTYPE' => 'bd_doktype',
'TJ.FRADATO' => 'tj_fradato',
'TG.FRADATO' => 'tg_fradato',
'DOKKATEGORI.TAB' => 'dokkategori',
'JE.JSARKIV1' => 'je_jsarkiv1',
'MERKNAD.TAB' => 'merknad',
'ADRTYPE.TAB' => 'adrtype',
'AD.LUKKET' => 'ad_lukket',
'SP.SAID' => 'sp_said',
'BS.KOLOSTE' => 'bs_koloste',
'FU.SEKR' => 'fu_sekr',
'AK.TYPE' => 'ak_type',
'AM.KOPIMOT' => 'am_kopimot',
'RO.NYSAK' => 'ro_nysak',
'AM.UTLAND' => 'am_utland',
'JP.AVSKDATO' => 'jp_avskdato',
'JP.JPOSTNR' => 'jp_jpostnr',
'SE.ID' => 'se_id',
'DU.MAL' => 'du_mal',
'JS.FOREKST' => 'js_forekst',
'FU.FUNK' => 'fu_funk',
'AR.ABASEID' => 'ar_abaseid',
'BS.BETEGN' => 'bs_betegn',
'SP.NAVN' => 'sp_navn',
'ER.ABASEID' => 'er_abaseid',
'TI.TGKODE' => 'ti_tgkode',
'ARKIVPERIODE.TAB' => 'arkivperiode',
'UT.OPPNAVUTV' => 'ut_oppnavutv',
'PL.PSID' => 'pl_psid',
'AD.TILDATO' => 'ad_tildato',
'UTVBEHANDLING.TAB' => 'utvbehandling',
'MD.AGDATO' => 'md_agdato',
'TILLEGGSINFO.TAB' => 'tilleggsinfo',
'PT.TGKODE' => 'pt_tgkode',
'UT.KODE' => 'ut_kode',
'AR.SKAPER' => 'ar_skaper',
'JO.ORDNVER1' => 'jo_ordnver1',
'UT.MONUMSER' => 'ut_monumser',
'OV.BEVTID' => 'ov_bevtid',
'SA.UTLDATO' => 'sa_utldato',
'AK.OVERORD' => 'ak_overord',
'UTVSAKTYP.TAB' => 'utvsaktyp',
'MO.STED' => 'mo_sted',
'PN.AKTIV' => 'pn_aktiv',
'ARSTATUS.TAB' => 'arstatus',
'AM.GRUPPE' => 'am_gruppe',
'SA.JENHET' => 'sa_jenhet',
'SG.SAKSTYPE' => 'sg_sakstype',
'PS.DATO' => 'ps_dato',
'PR.TITTEL' => 'pr_tittel',
'DL.JPID' => 'dl_jpid',
'ER.JPID' => 'er_jpid',
'JP.NDOKTYPE' => 'jp_ndoktype',
'DS.BETEGN' => 'ds_betegn',
'JENARKDEL.TAB' => 'jenarkdel',
'AM.ID' => 'am_id',
'DU.ALDRIJOUR' => 'du_aldrijour',
'RO.REGADM' => 'ro_regadm',
'DB.AGKODE' => 'db_agkode',
'MO.DATO' => 'mo_dato',
'ME.TGKODE' => 'me_tgkode',
'DT.KODE' => 'dt_kode',
'ER.ADMID' => 'er_admid',
'TJ.AUTOPPAV' => 'tj_autoppav',
'FRAMMOTE.TAB' => 'frammote',
'JP.STATUS' => 'jp_status',
'AM.SBHID' => 'am_sbhid',
'MD.ARKKODE' => 'md_arkkode',
'TL.BETEGN' => 'tl_betegn',
'PR.ADMID' => 'pr_admid',
'EARKKODE.TAB' => 'earkkode',
'UT.BESKR' => 'ut_beskr',
'JE.JENHET' => 'je_jenhet',
'AD.PRIMKOD' => 'ad_primkod',
'VE.VARIANT' => 've_variant',
'AK.ADRGRUPPE' => 'ak_adrgruppe',
'PN.PEID' => 'pn_peid',
'VE.LAGRENH' => 've_lagrenh',
'SG.SISTEVEDT' => 'sg_sistevedt',
'AK.REGEPOST' => 'ak_regepost',
'ALIASADMENH.TAB' => 'aliasadmenh',
'MO.UTVID' => 'mo_utvid',
'DI.SIGNNR' => 'di_signnr',
'ME.SAID' => 'me_said',
'VE.DOKFORMAT' => 've_dokformat',
'SK.NUMSER' => 'sk_numser',
'UT.OPPNAV' => 'ut_oppnav',
'SV.SSSAKSBH' => 'sv_sssaksbh',
'TG.OPPRAV' => 'tg_opprav',
'AK.ADRID' => 'ak_adrid',
'JA.JENHET' => 'ja_jenhet',
'SA.U1' => 'sa_u1',
'AG.KODE' => 'ag_kode',
'NU.AARAUTO' => 'nu_aarauto',
'FU.PNID' => 'fu_pnid',
'ME.RNR' => 'me_rnr',
'LK.KODE' => 'lk_kode',
'OP.TYPE' => 'op_type',
'TGKODE.TAB' => 'tgkode',
'ME.ITYPE' => 'me_itype',
'TJ.AUTAV' => 'tj_autav',
'EOPRESEDENS.TAB' => 'eopresedens',
'SA.KASSDATO' => 'sa_kassdato',
'UT.ARKDEL' => 'ut_arkdel',
'AV.BESVART' => 'av_besvart',
'PN.FRADATO' => 'pn_fradato',
'EA.ORDNVER' => 'ea_ordnver',
'ER.REF' => 'er_ref',
'PS.DOKID' => 'ps_dokid',
'SS.STATUS' => 'ss_status',
'PR.JENHET' => 'pr_jenhet',
'OP.EVAUTO' => 'op_evauto',
'SA.UTLTIL' => 'sa_utltil',
'JP.AGKODE' => 'jp_agkode',
'DI.SIGNTEKST' => 'di_signtekst',
'AI.ADMKORT' => 'ai_admkort', 
                'OV.KASREGEL' => 'ov_kasregel', 
                'SE.TILDATO' => 'se_tildato', 
                'JE.TILDATO' => 'je_tildato',
'ER.SBHINIT' => 'er_sbhinit',
'BD.NDOKTYPE' => 'bd_ndoktype',
'MD.BEVTID' => 'md_bevtid',
'PG.PERROLID' => 'pg_perrolid',
'LK.BETEGN' => 'lk_betegn',
'EP.SORDFLAGG' => 'ep_sordflagg',
'PERSON.TAB' => 'person',
'UM.TILDATO' => 'um_tildato',
'RO.ETILG' => 'ro_etilg',
'JS.FORINT' => 'js_forint',
'TK.TGKODE' => 'tk_tgkode',
'SA.SAAR' => 'sa_saar',
'PO.OPRDATO' => 'po_oprdato',
'TK.BETEGN' => 'tk_betegn',
'ORDNPRINS.TAB' => 'ordnprins',
'PO.POSTNR' => 'po_postnr',
'AK.EPOST' => 'ak_epost',
'SP.ROLLE' => 'sp_rolle',
'UTVMOTEDOK.TAB' => 'utvmotedok',
'PG.INNMAV' => 'pg_innmav',
'TJ.PEID' => 'tj_peid',
'MG.MEDLID' => 'mg_medlid', 
                'JF.FJPID' => 'jf_fjpid', 
                'OV.KASKODE' => 'ov_kaskode', 
                'MD.STATUS' => 'md_status', 
                'MO.SLUTT' => 'mo_slutt', 
                'MD.TGKODE' => 'md_tgkode', 
                'AV.KODE' => 'av_kode',
'PH.MERKNAD' => 'ph_merknad',
'DL.TKAV' => 'dl_tkav',
'KL.ORDNVER' => 'kl_ordnver',
'AS.SPEFDOK' => 'as_spefdok',
'AD.NUMSER' => 'ad_numser',
'SV.ADMID' => 'sv_admid',
'US.TGKODE' => 'us_tgkode',
'DI.DOKSIGN' => 'di_doksign',
'ER.ASAAR' => 'er_asaar',
'SK.DOKIH' => 'sk_dokih',
'FU.SORT' => 'fu_sort',
'PA.PEID' => 'pa_peid',
'EOHENV.TAB' => 'eohenv',
'AR.FRADATO' => 'ar_fradato',
'ME.REGDATO' => 'me_regdato',
'BK.BETEGN' => 'bk_betegn',
'SA.BEVTID' => 'sa_bevtid',
'FM.KODE' => 'fm_kode',
'RO.SOK' => 'ro_sok',
'SP.POSTNR' => 'sp_postnr',
'TI.REGAV' => 'ti_regav',
'ND.INTMOT' => 'nd_intmot',
'PH.TPSID' => 'ph_tpsid',
'FORSMAATE.TAB' => 'forsmaate',
'POSTNR.TAB' => 'postnr',
'SV.TGSAK' => 'sv_tgsak',
'JE.JSARKIV2' => 'je_jsarkiv2',
'KT.TGKODE' => 'kt_tgkode',
'LF.BESKRIV' => 'lf_beskriv',
'SP.U1' => 'sp_u1',
'MO.PROTOKOLL' => 'mo_protokoll',
'TI.JPID' => 'ti_jpid',
'TH.AGDAGER' => 'th_agdager',
'SA.PAPIR' => 'sa_papir',
'SG.VEDTDATO' => 'sg_vedtdato',
'NOARKSAK.TAB' => 'noarksak',
'SG.UOFF' => 'sg_uoff',
'AP.PERIODE' => 'ap_periode',
'JP.UDATERT' => 'jp_udatert',
'SP.FAKS' => 'sp_faks',
'DIGISERT.TAB' => 'digisert',
'MD.SBHID' => 'md_sbhid',
'ADRPERSON.TAB' => 'adrperson',
'TI.SAID' => 'ti_said',
'STDVERDI.TAB' => 'stdverdi',
'VE.DOKID' => 've_dokid',
'ARKIV.TAB' => 'arkiv',
'SP.EPOSTADR' => 'sp_epostadr',
'JP.AGDATO' => 'jp_agdato',
'BD.DOKID' => 'bd_dokid',
'SS.UTG' => 'ss_utg',
'AK.TLF' => 'ak_tlf',
'US.TITTEL' => 'us_tittel',
'RO.NYJPOSTE' => 'ro_nyjposte',
                'UB.PROTOKOLL' => 'ub_protokoll',
                'JP.UOFF' => 'jp_uoff',
                'JP.OVDATO' => 'jp_ovdato',
                'IT.LTEKST1' => 'it_ltekst1',
                'TI.DOKVER' => 'ti_dokver',
                'ER.SBHNAVN' => 'er_sbhnavn',
                'UM.VARAFOR' => 'um_varafor',
                'BD.BEHID' => 'bd_behid',
                'SA.ANSVID' => 'sa_ansvid',
                'AM.FORSEND' => 'am_forsend',
                'JOURNSTATUS.TAB' => 'journstatus',
                'AR.TILDATO' => 'ar_tildato',
                'UTVBEHSTAT.TAB' => 'utvbehstat',
                'JP.ANTVED' => 'jp_antved',
                'UB.MOID' => 'ub_moid',
                'PS.HJEMMEL' => 'ps_hjemmel',
                'AI.TILDATO' => 'ai_tildato',
                'PA.ADRID' => 'pa_adrid',
                'ENHETSTYPE.TAB' => 'enhetstype',
                'SA.KASSKODE' => 'sa_kasskode',
                'SP.ADRESSE' => 'sp_adresse',
                'DB.LOKPAPIR' => 'db_lokpapir',
                'JF.ID' => 'jf_id',
                'MO.NR' => 'mo_nr',
                'DT.MOTEDOK' => 'dt_motedok',
                'PS.ID' => 'ps_id',
                'RO.ESDEL' => 'ro_esdel',
                'KA.TGKODE' => 'ka_tgkode',
                'SA.ARKDEL' => 'sa_arkdel',
                'OP.EVOK' => 'op_evok',
                'JE.JSSAKSBH2' => 'je_jssaksbh2',
                'AS.BETEGN' => 'as_betegn',
                'ML.MDPID' => 'ml_mdpid',
'MD.INNHOLD' => 'md_innhold',
'RO.RMERKN' => 'ro_rmerkn',
'US.MERKNAD' => 'us_merknad',
'JP.ARKDEL' => 'jp_arkdel',
'FU.MERKNAD' => 'fu_merknad',
'SE.VERDATO' => 'se_verdato',
'TJ.JENHET' => 'tj_jenhet',
'ME.DOKVER' => 'me_dokver',
'SG.KLADGANG' => 'sg_kladgang',
'DK.KODE' => 'dk_kode',
'FUNGROLLE.TAB' => 'fungrolle',
'PN.MNAVN' => 'pn_mnavn',
'TI.ITYPE' => 'ti_itype',
'DB.DOKID' => 'db_dokid',
'AD.ARKIV' => 'ad_arkiv',
'MO.FRIST' => 'mo_frist',
'MEDLADRGR.TAB' => 'medladrgr',
'PRESEDENS.TAB' => 'presedens',
'DI.VARIANT' => 'di_variant',
'JO.ORDNVER2' => 'jo_ordnver2',
'FS.STATUS' => 'fs_status',
'MK.SEKR' => 'mk_sekr',
'AM.KORTNAVN' => 'am_kortnavn',
'AM.AVSKM' => 'am_avskm',
'AVSKRMAATE.TAB' => 'avskrmaate',
'MO.ID' => 'mo_id',
'KK.KODE' => 'kk_kode',
'LA.KODE' => 'la_kode',
'RO.ARKKON' => 'ro_arkkon',
'MD.TGGRUPPE' => 'md_tggruppe',
'SE.NAVN' => 'se_navn',
'BA.UBID2' => 'ba_ubid2',
'RO.EKLASS' => 'ro_eklass',
'AD.PAPIR' => 'ad_papir',
'TK.RANG' => 'tk_rang',
'UM.SEKR' => 'um_sekr',
'FS.BETEGN' => 'fs_betegn',
'PS.JPID' => 'ps_jpid',
'MK.KODE' => 'mk_kode',
'AD.LOK' => 'ad_lok',
'AR.PRIMNOK' => 'ar_primnok',
'UT.FRADATO' => 'ut_fradato',
'AD.SPEFSAK' => 'ad_spefsak',
'JS.FORARKIV' => 'js_forarkiv',
'RO.ROLLEID' => 'ro_rolleid',
'STATUSMDOK.TAB' => 'statusmdok',
'ORDNVERDI.TAB' => 'ordnverdi',
'AM.BEHANSV' => 'am_behansv',
'SE.TTPEPOST' => 'se_ttpepost',
'UT.MOTEFORM' => 'ut_moteform',
'AK.FAKS' => 'ak_faks',
'ER.SBHID' => 'er_sbhid',
'OV.TGKODE' => 'ov_tgkode',
'ND.EKSTPROD' => 'nd_ekstprod',
'UTVMEDLFUNK.TAB' => 'utvmedlfunk',
'ST.TYPE' => 'st_type',
'JP.JDATO' => 'jp_jdato',
'TI.DOKID' => 'ti_dokid',
'AD.FORTS' => 'ad_forts',
'JO.MERKNAD' => 'jo_merknad',
'AI.ID' => 'ai_id',
'RO.EKSPDOK' => 'ro_ekspdok',
'SA.SEKNR' => 'sa_seknr',
'SK.UTVSNR' => 'sk_utvsnr',
'AK.POSTSTED' => 'ak_poststed',
'UTVTYPE.TAB' => 'utvtype',
'KPFORMAT.TAB' => 'kpformat',
'IT.LTEKST2' => 'it_ltekst2',
'SAKSPART.TAB' => 'sakspart',
'SK.UTVID' => 'sk_utvid',
'AK.PERSOK' => 'ak_persok',
'ME.PVGAV' => 'me_pvgav',
'AD.MERKNAD' => 'ad_merknad',
'MD.AGKODE' => 'md_agkode',
'IT.OPPBETID' => 'it_oppbetid',
'BS.KANSKART' => 'bs_kanskart',
'VE.REGAV' => 've_regav',
'TG.GRUPPEID' => 'tg_gruppeid',
'TI.TEKST' => 'ti_tekst',
'ARKIVDEL.TAB' => 'arkivdel',
'AP.STATUS' => 'ap_status',
'SK.KUNOVSKR' => 'sk_kunovskr',
'DU.BETEGN' => 'du_betegn',
'UT.TILDATO' => 'ut_tildato',
'SA.TITTEL' => 'sa_tittel',
'KL.MERKNAD' => 'kl_merknad',
'TK.TILDATO' => 'tk_tildato',
'US.TGGRUPPE' => 'us_tggruppe',
'RO.ARKLEDER' => 'ro_arkleder',
'EP.ORD' => 'ep_ord',
'TLKODE.TAB' => 'tlkode',
'ST.UOFF' => 'st_uoff',
'UT.ANTMEDL' => 'ut_antmedl',
'PG.PEID' => 'pg_peid',
'AR.BETEGN' => 'ar_betegn',
'RO.EFRIST' => 'ro_efrist',
'UT.ADMID' => 'ut_admid',
'AP.ARKIV' => 'ap_arkiv',
'PG.GRUPPEID' => 'pg_gruppeid',
'SAKSTATUS.TAB' => 'sakstatus',
'SA.OBS' => 'sa_obs',
'AM.FSSTATUS' => 'am_fsstatus',
'UT.NEDLAGT' => 'ut_nedlagt',
'US.SAID' => 'us_said',
'TH.AGAAR' => 'th_agaar',
'SA.PRES' => 'sa_pres',
'JF.FSAID' => 'jf_fsaid',
'SU.KODE' => 'su_kode',
'IT.AUTOLOG' => 'it_autolog',
'SK.AVS' => 'sk_avs',
'SE.SIGNTEKST' => 'se_signtekst',
'AI.IDFAR' => 'ai_idfar',
'EP.PSID' => 'ep_psid',
'US.U1' => 'us_u1',
'SP.UTLAND' => 'sp_utland',
'MK.FMKODE' => 'mk_fmkode',
'MG.GRID' => 'mg_grid',
'AV.BETEGN' => 'av_betegn',
'VE.AKTIV' => 've_aktiv',
'US.POLSGID' => 'us_polsgid',
'UM.RANGERING' => 'um_rangering',
'TH.TGKODE' => 'th_tgkode',
'OP.MAKSLEN' => 'op_makslen',
'SV.BFFRIST1' => 'sv_bffrist1',
'NU.ID' => 'nu_id',
'DB.STATUS' => 'db_status',
'DL.TYPE' => 'dl_type',
'AL.ADMIDFRA' => 'al_admidfra',
'MOTEDOKLINK.TAB' => 'motedoklink',
'AM.JPID' => 'am_jpid',
'JS.FORSAKSBEH' => 'js_forsaksbeh',
'UM.FUNK' => 'um_funk',
'AK.ORGNR' => 'ak_orgnr',
'PO.KOMNR' => 'po_komnr',
'TI.VARIANT' => 'ti_variant',
'TJ.TILDATO' => 'tj_tildato',
'OV.SEKFLAGG' => 'ov_sekflagg',
'VE.OPPBEDATO' => 've_oppbedato',
'SA.ADMID' => 'sa_admid',
'ND.DOKTYPE' => 'nd_doktype',
'ET.UNDEREN' => 'et_underen',
'PO.NEDLDATO' => 'po_nedldato',
'ST.HJEMMEL' => 'st_hjemmel',
'KL.U1' => 'kl_u1',
'JS.EKSPEDERT' => 'js_ekspedert',
'NUMSERIE.TAB' => 'numserie',
'US.ID' => 'us_id',
'AM.REF' => 'am_ref',
'MO.SAKSKART' => 'mo_sakskart',
'IT.BETEGN' => 'it_betegn',
'SE.ADRID' => 'se_adrid',
'OP.KLFLAGG' => 'op_klflagg',
'JF.TSAID' => 'jf_tsaid',
'LFKODER.TAB' => 'lfkoder',
'OV.ORDNPRI' => 'ov_ordnpri',
'SA.TGKODE' => 'sa_tgkode', 
'PO.KOMMUNE' => 'po_kommune',
'OV.ARKDEL' => 'ov_arkdel',
'PN.FORNAVN' => 'pn_fornavn',
'SV.SSARKIV' => 'sv_ssarkiv',
'SA.TYPE' => 'sa_type',
'AM.IHTYPE' => 'am_ihtype',
'RO.REGUTVMED' => 'ro_regutvmed',
'SV.TGJP2' => 'sv_tgjp2',
'EA.ORDNPRI' => 'ea_ordnpri',
'ST.BETEGN' => 'st_betegn',
'BS.BEHANDLET' => 'bs_behandlet',
'PT.AUTOPPAV' => 'pt_autoppav',
'UTVBEHDOK.TAB' => 'utvbehdok',
'PG.MEDKOD' => 'pg_medkod',
'PR.PEID' => 'pr_peid',
'MD.KASSKODE' => 'md_kasskode',
'TI.RNR' => 'ti_rnr',
'RO.REGPERSON' => 'ro_regperson',
'OP.TGKODE' => 'op_tgkode',
'AR.NUMSER' => 'ar_numser',
'PR.ID' => 'pr_id',
'AM.ADRESSE' => 'am_adresse',
'ET.KODE' => 'et_kode',
'RO.ETKLASS' => 'ro_etklass',
'AV.MIDLERTID' => 'av_midlertid',
'KPAUTORIS.TAB' => 'kpautoris',
'PN.TILDATO' => 'pn_tildato',
'JP.ID' => 'jp_id',
'NU.AAR' => 'nu_aar',
'UT.TYPE' => 'ut_type',
'AK.TGGRUPPE' => 'ak_tggruppe',
'AM.JENHET' => 'am_jenhet',
'SK.ARKSDNR' => 'sk_arksdnr',
'SV.BFFRIST2' => 'sv_bffrist2',
'JP.TLKODE' => 'jp_tlkode',
'PH.FPSID' => 'ph_fpsid',
'LF.KODE' => 'lf_kode',
'MO.UOFF' => 'mo_uoff',
'JF.TJPID' => 'jf_tjpid',
'JE.LOK' => 'je_lok' };
 
    return $VAR1;
}
