#!/usr/bin/perl
#---------------------------------------------------------------------
# $Id: 003.createdb.t 579 2011-05-31 12:15:39Z tm $
#---------------------------------------------------------------------
# automated test of db creation.

use strict;
use warnings;

BEGIN {
    system('cp', './t/arkn4.conf', './src/');
    system('cp', './lib/Noark/Config/tablemap.conf', './src/');
    system('cp', './lib/Noark/Config/dtdmap.conf', './src/');
}

END {
    # Cleanup:
    system('rm', './src/arkn4.conf');
    system('rm', './src/tablemap.conf');
    system('rm', './src/dtdmap.conf');
}

my $CREATEDB = './src/arkn4_createdb';

use Data::Dumper;

use Noark::Config qw($config);
use Noark::Db;
use Test::Differences;
use Test::More;

#-----------------------------------------------------------------------------
# Give user a friendly way out if MySQL is not configured yet.
my $str = <<EOF;

------------------------------------------------------------------------------
These tests assume your MySQL-server is configured for use with ArkN4. You
need to create a user for arkn4 that can connect to the server with a
password. The current configuration uses the following default:
  User:       $config->{DB_USER}
  Password:   $config->{DB_PASS}
  Server:     $config->{DB_HOST}
------------------------------------------------------------------------------
EOF

# print STDERR $str;
# print STDERR "Do you want to run the database tests? [y/N] ";

# my $answer = <>;
# chomp $answer;
# $answer = "n" unless $answer;
# $answer = ($answer =~ /^y/i) ? 1 : 0;
# print STDERR "-" x 78, "\n";

# if ($answer) {
my $answer = 1;
plan tests => 6;
# } else {
#     plan skip_all => "MySQL-server not configured yet.";
# }
# End of way out when MySQL is not configured.
#-----------------------------------------------------------------------------

my $user     = $config->{DB_USER};
my $host     = $config->{DB_HOST};
my $password = $config->{DB_PASS};
my $name     = "arkN4t1";

# Check that I can connect to a database:
eval {
    my $db = Noark::Db->new({database => 'test',
			     user     => $user,
			     password => $password});
};

print $@ if $@;

BAIL_OUT($str) if $@;

ok(!$@, "Connecting to database");

SKIP: {
    skip "Cannot connect to Database. MySQL not configured yet", 5 if $@;

    my $re1 = qx($CREATEDB -n $name) if $answer;
    my $ok1 = <<EOF;
Oppretter database:
     dbuser: '$user'
     dbname: '$name'
     dbhost: '$host'
  [OK]

Oppretter tabeller:
    modul_14.2_arkivstyring_tabeller.sql              [OK]
    modul_14.3_el_arkiv_tabeller.sql                  [OK]
    modul_14.4_adm_opp_ark_tabeller.sql               [OK]
    modul_14.5_tilgang_brukeradm_tabeller.sql         [OK]
    modul_14.6_utvalgsbehandling_tabeller.sql         [OK]
    modul_14.7_standardverdier_tabeller.sql           [OK]



EOF

    eq_or_diff($re1, $ok1,
               "testing creating db with --no-keys");


    my $re2 = qx($CREATEDB -n $name --only-keys) if $answer;
    my $ok2 = <<EOF;
Oppretter referanser:
    modul_14.2_arkivstyring_referanser.sql            [OK]
    modul_14.3_el_arkiv_referanser.sql                [OK]
    modul_14.4_adm_opp_ark_referanser.sql             [OK]
    modul_14.5_tilgang_brukeradm_referanser.sql       [OK]
    modul_14.6_utvalgsbehandling_referanser.sql       [OK]
    modul_14.7_standardverdier_referanser.sql         [OK]



EOF

    eq_or_diff($re2, $ok2,
               "testing adding keys to an existing database");

    my $re3 = qx($CREATEDB -n arkN4t1 --drop-db) if $answer;
    my $ok3 = <<EOF;
Database "arkN4t1" dropped
[OK]

EOF

    eq_or_diff($re3, $ok3,
               "testing dropping db.");


    my $re4 = qx($CREATEDB -n arkN4t2 --keys) if $answer;
    my $ok4 = <<EOF;
Oppretter database:
     dbuser: '$user'
     dbname: 'arkN4t2'
     dbhost: '$host'
  [OK]

Oppretter tabeller:
    modul_14.2_arkivstyring_tabeller.sql              [OK]
    modul_14.3_el_arkiv_tabeller.sql                  [OK]
    modul_14.4_adm_opp_ark_tabeller.sql               [OK]
    modul_14.5_tilgang_brukeradm_tabeller.sql         [OK]
    modul_14.6_utvalgsbehandling_tabeller.sql         [OK]
    modul_14.7_standardverdier_tabeller.sql           [OK]

Oppretter referanser:
    modul_14.2_arkivstyring_referanser.sql            [OK]
    modul_14.3_el_arkiv_referanser.sql                [OK]
    modul_14.4_adm_opp_ark_referanser.sql             [OK]
    modul_14.5_tilgang_brukeradm_referanser.sql       [OK]
    modul_14.6_utvalgsbehandling_referanser.sql       [OK]
    modul_14.7_standardverdier_referanser.sql         [OK]



EOF

    eq_or_diff($re4, $ok4,
               "testing creating db with keys");

    my $re5 = qx($CREATEDB -n arkN4t2 --drop-db) if $answer;
    my $ok5 = <<EOF;
Database "arkN4t2" dropped
[OK]

EOF

    eq_or_diff($re5, $ok5,
               "testing dropping db with keys.");


}
