#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id: 010.noark_error.t 639 2011-06-10 13:04:36Z tm $
#-----------------------------------------------------------------------------
# Tests for Noark::Error

use strict;
use warnings;

use Data::Dumper;
use Test::Differences;
use Test::More tests => 13;

BEGIN {
    use_ok('Noark::Error');
}

my $date = ''.localtime();
my $err = Noark::Error->new(name => 'Dette er en test på feilmelding',
                            text => 'Testen du skal teste genererere denne '
                                  . 'feilmeldingen av typen ##TYPE##, for at '
                                  . 'du skal se at feil meldingen virker som '
                                  . 'den skal. dato: ##DATO##, Ikke: ##IKKE##',
                            variables => {TYPE => 'Noark::Error',
                                          DATO => $date,}
                           );


isa_ok($err, 'Noark::Error');

can_ok('Noark::Error', 
       qw(new               add_variable    add_listing 
          get_listing       get_text        get_name        set_file
          increment_counter get_list_labels set_list_labels get_file));


my $text = 'Testen du skal teste genererere denne feilmeldingen av typen '
         . 'Noark::Error, for at du skal se at feil meldingen virker som den '
         . 'skal. dato: '.$date.', Ikke: ##IKKE##';

eq_or_diff($err->get_text(), $text, "Tester Noark::Error::get_text()");

ok($err->add_variable(IKKE => 'Nå ble den satt'), 
   'Tester Noark::Error::add_variable (1)');

my $txt2 = 'Testen du skal teste genererere denne feilmeldingen av typen '
         . 'Noark::Error, for at du skal se at feil meldingen virker som den '
         . 'skal. dato: '.$date.', Ikke: Nå ble den satt';

cmp_ok($err->get_text(), 'eq', $txt2,
       'Tester Noark::Error::add_variable (2)');


ok($err->set_list_labels(qw(label1 label2 label3 label4)),
   'Testing Noark::Error::set_list_labels()');

my $labels = [qw(label1 label2 label3 label4)];

eq_or_diff($err->get_list_labels(), $labels, 
          'Testing Noark::Error::get_list_labels()');


eval {
    $err->add_listing('verdi1', 'verdi2');
};

ok($@, "Testing that Noark::Error::add_listing croaks on error.");

ok($err->add_listing(qw(verdi1 verdi2 verdi3 verdi4)),
  "Testing Noark::Error::add_listing");
ok($err->add_listing(qw(verdi1b verdi2b verdi3b verdi4b)));


# print Dumper $err->get_listing();

my $list = [
          [
            'verdi1',
            'verdi2',
            'verdi3',
            'verdi4'
          ],
          [
            'verdi1b',
            'verdi2b',
            'verdi3b',
            'verdi4b'
          ]
        ];

eq_or_diff($err->get_listing(), $list, 'Testing Noark::Error::get_listing');

is($err->get_name(), 'Dette er en test på feilmelding',
   'Testing Noark::Error::get_name()');
