#!/usr/bin/perl

use strict;
use warnings;
use Data::Dumper;

use Test::More tests => 6;
use Test::Differences;

BEGIN { use_ok 'Noark::Error::MissingAttribute'; }


my $error = Noark::Error::MissingAttribute->new(table => 'NOARKSAK');
isa_ok($error, 'Noark::Error::MissingAttribute');

$error->add_attributes({
    attributes => [qw(SA.ID SA.DATO SA.TITTEL SA.OBS SA.TYPE)],
    table => 'NOARKSAK',
});


# print Dumper $error->get_attributes();
my $expected = {
    'SA.ID'     => 'K=O,O=x',
    'SA.TYPE'   => 'K=A,O= ',
    'SA.TITTEL' => 'K=O,O=x',
    'SA.DATO'   => 'K=O,O=x',
};

is_deeply($error->get_attributes, $expected, "Getting correct list");
ok($error->{__got_ox}, "Found Ox");

# print Dumper $error->to_text("2.1.1.", 4);
# exit

can_ok($error, qw|to_text|);
my $expect_to_text = <<BAM;
    2.1.1. Attributter mangler i XML-fil

      Et eller flere av attributtene som mangler har kravtype K=O,O=x. Dette 
      vil si at attributtet er del av en obligatorsk tabell og SKAL inneholde 
      data. Det er i utgangspunktet en feil at dette mangler. 

      Flgende attributter er definert i NOARKIH, men mangler i avleveringen 

        Attributt                 Krav type   
        ------------------------  ------------
        SA.DATO                   K=O,O=x     
        SA.ID                     K=O,O=x     
        SA.TITTEL                 K=O,O=x     
        SA.TYPE                   K=A,O=      
BAM

eq_or_diff_text($error->to_text("2.1.1.", 4), $expect_to_text, 'Testing to_text');
