#!/usr/bin/perl
#-----------------------------------------------------------------------
# $Id: 013.noark_error_potentialduplicatekey.t 671 2011-06-16 08:44:21Z tm $
#-----------------------------------------------------------------------

use strict;
use warnings;

use Test::More tests => 9;

BEGIN {
    use_ok 'Noark::Error::PotentialDuplicateKey';
}

my $err = Noark::Error::PotentialDuplicateKey->new();

isa_ok($err, 'Noark::Error::PotentialDuplicateKey');

# print $err->get_text();

my $txt = 'Det ble funnet primrnkler som etter normalisering var identiske. '
        . 'Dette kommer av at det er brukt tegn som mellomrom eller '
        . 'linjeskift i primrnkkelen og det eneste som skiller nklene fra '
        . 'hverandre er forskjellig antall blanke tegn. Dette er ikke '
        . 'ndvendigvis en feil i avleveringen, men kan skyldes en '
        . 'kuriositet i arkivsystemet.';

is($err->get_text(), $txt, "Testing text");

ok($err->add_line({
    pk   => 't e s t',
    norm => 'test',
    file => 'test.xml',
    line => 127
}));
ok($err->add_line({
    pk => 'nummer    to',
    norm => 'nummerto', 
    file => 'test.xml',
    line => 4
}));
ok($err->add_line({
    pk   => 'n u mmer    to',
    norm => 'nummerto',
    file => 'test.xml', 
    line => 81
}));

my $keys = {
    'test' => {
        'test.xml' => {
            't e s t' => {
                127 => 1
            }
        }
    },
    'nummerto' => {
        'test.xml' => {
            'n u mmer    to' => {
                81 => 1
            },
            'nummer    to' => {
                4 => 1
            }
        }
    }
};

is_deeply($err->get_keys(), $keys, "Testing getting keys");

can_ok($err, qw|to_text|);

my $expect_to_text = <<BAM;
  Potensiell duplikat nkkelverdi

  Det ble funnet primrnkler som etter normalisering var identiske. Dette 
  kommer av at det er brukt tegn som mellomrom eller linjeskift i 
  primrnkkelen og det eneste som skiller nklene fra hverandre er 
  forskjellig antall blanke tegn. Dette er ikke ndvendigvis en feil i 
  avleveringen, men kan skyldes en kuriositet i arkivsystemet. 

    Filnavn       Norm.Nkkel          Linje  Nkkel                  
    ------------  ----------------  --------  ------------------------
    test.xml      nummerto                81  n u mmer    to          
    test.xml      nummerto                 4  nummer    to            
    test.xml      test                   127  t e s t                 
BAM

is($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');

