#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id: 014.noark_error_duplicatekey.t 660 2011-06-15 13:34:15Z tm $
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 12;

BEGIN {
    use_ok('Noark::Error::DuplicateKey');
}

my $err = Noark::Error::DuplicateKey->new();

isa_ok($err, 'Noark::Error::DuplicateKey');

is(
    $err->get_text(),
    'Det ble funnet en rad hvor verdien i nkkelraden(e) var en duplikat ' .
    'av en tidligere importert rad.',
    'output from get_text()'
);

ok(! eval {
    $err->add_line({
        pk => 'test',
    });
}, 'Using add_line incorrectly causes croak');

ok(
    $@ =~ /You must supply a value for 'file' in arguments/, 
    'Testing output from croak'
);

is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    pk   => 'test',
    file => 'test.xml',
    line => 100,
    table => 'NOARKSAK',
}), 'Noark::Error::DuplicateKey');
isa_ok($err->add_line({
    pk   => 'test',
    file => 'test.xml',
    line => 200,
    table => 'NOARKSAK',
}), 'Noark::Error::DuplicateKey');
isa_ok($err->add_line({
    pk   => 'test',
    file => 'test2.xml',
    line => 100,
    table => 'NOARKSAK',
}), 'Noark::Error::DuplicateKey');

is_deeply(
    $err->{__keys}, {
        'test2.xml' => {
            '100' => { 'SA.ID' => { 'test' => 1 } },
        },
        'test.xml' => {
            '200' => {'SA.ID' => { 'test' => 1 }},
            '100' => {'SA.ID' => { 'test' => 1 }},
           }
    },
    "Testing integrty of errors after insert"
);

can_ok($err, qw|to_text|);

my $expect_to_text = <<BAM;
  Duplikat nkkelverdi

  Det ble funnet en rad hvor verdien i nkkelraden(e) var en duplikat av en 
  tidligere importert rad. 

    Filnavn         Linje            Nkkel    Verdi                   
    ------------  -------  ----------------    ------------------------
    test.xml          100             SA.ID == test                    
    test.xml          200             SA.ID == test                    
    test2.xml         100             SA.ID == test                    
BAM

# print "---";
# print $err->to_text(undef, 2);
# print "---";
# print $expect_to_text;
# print "---";

is($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
