#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id: 015.noark_error_duplicateunique.t 799 2011-06-28 14:27:54Z tm $
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 8;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::DuplicateUnique');
}

my $err = Noark::Error::DuplicateUnique->new();

isa_ok($err, 'Noark::Error::DuplicateUnique');


is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    field  => 'test',
    file   => 'test.xml',
    lines => [100, 129],
    value => 'brumbrum',
    datatype => 'VARCHAR(10)',
}), 'Noark::Error::DuplicateUnique');
isa_ok($err->add_line({
    field  => 'test',
    file   => 'test.xml',
    lines => [132, 148],
    value => 'foobar',
    datatype => 'VARCHAR(10)',
}), 'Noark::Error::DuplicateUnique');

is_deeply(
    $err->{__keys}, {
        'test.xml' => {
            '132' => {
                '148' => {
                    'test' => {
                        'foobar' => {
                            'VARCHAR(10)' => 1
                           }
                       }
                   }
               },
            '100' => {
                '129' => {
                    'test' => {
                        'brumbrum' => {
                            'VARCHAR(10)' => 1
                           }
                       }
                   }
               }
           }
           
       }, 
    'Testing integrity of error hash.'
);

can_ok($err, qw|to_text|);

my $expect_to_text = <<BAM;
  Duplikat verdi for felt som er UNIQUE

  Vi fant en eller flere felt som hadde duplikate verdier der verdien er 
  definert til  vre unik iht. Noark-4.1. 

    Filnavn        Linje 1   Linje 2            Nkkel  Datatype        
    ------------  --------  --------  ----------------  ----------------
    test.xml           100       129              test  VARCHAR(10)     
    test.xml           132       148              test  VARCHAR(10)     
BAM

is($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
