#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id: 016.noark_error_foreignkey.t 788 2011-06-28 13:26:44Z tm $
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 8;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::ForeignKey');
}

my $err = Noark::Error::ForeignKey->new();

isa_ok($err, 'Noark::Error::ForeignKey');

is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    field     => 'db_kategori',
    value     => 'foobar',
    requirement => 'O2 => O2',
    ref_field => 'dk_kode', 
    table     => 'dokbeskriv',
    ref_table => 'dokkategori',
}), 'Noark::Error::ForeignKey');
isa_ok($err->add_line({
    field     => 'db_status',
    value     => 'OK',
    requirement => 'O2 => O2',
    ref_field => 'ds_status', 
    table     => 'dokbeskriv',
    ref_table => 'dokstatus',
}), 'Noark::Error::ForeignKey');

# print Dumper $err->{__keys};
# exit();

is_deeply(
    $err->{__keys},
    {
        'dokbeskriv' => {
            'db_kategori' => {
                'dokkategori' => {
                    'dk_kode' => {
                        'foobar' => {
                            'O2 => O2' => 1
                           }
                       }
                   }
               },
            'db_status' => {
                'dokstatus' => {
                    'ds_status' => {
                        'OK' => {
                            'O2 => O2' => 1
                           }
                       }
                   }
               }
           }
       },
    "Testing integrity of error hash"
);

# print Dumper $err->to_text(undef, 2);
# exit;

can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
  Fremmednkkelfeil

  Det er funnet rad(er) i tabellen med ugyldig, men obligatorisk, 
  fremmednkkelreferanse. Verdien manglet i tabellen det refereres til. 
  Attributtet kan ogs ha blitt ugyldiggjort under database-importen hvis det 
  inneholdt en ugyldig verdi iht. Noark-4.1. Dette gjelder flgende nkler: 

    Nkkel (Verdi)            Antall  Referanse                 Krav    
    ------------------------  ------  ------------------------  --------
    db_kategori (foobar)           1  dokkategori : dk_kode     O2 => O2
    db_status (OK)                 1  dokstatus : ds_status     O2 => O2
BAM

eq_or_diff_text($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
