#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id: 017.noark_error_null.t 799 2011-06-28 14:27:54Z tm $
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 9;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::Null');
}

my $err = Noark::Error::Null->new();

isa_ok($err, 'Noark::Error::Null');

is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    field => 'sa_status',
    file  => 'NOARKSAK.XML',
    line  => '112',
}), 'Noark::Error::Null');
isa_ok($err->add_line({
    field => 'sa_dato',
    file  => 'NOARKSAK.XML',
    line  => '108',
}), 'Noark::Error::Null');
isa_ok($err->add_line({
    field => 'sa_dato',
    file  => 'NOARKSAK.XML',
    line  => '128',
}), 'Noark::Error::Null');

is_deeply(
    $err->{__keys}, {
        'sa_dato' => {
            'NOARKSAK.XML' => {
                '108' => 1,
                '128' => 1,
               }
           },
        'sa_status' => {
            'NOARKSAK.XML' => {
                '112' => 1
               }
           }
       },
    "Testing integrity of error hash"
);


can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
  Mangler verdi i felt som krever verdi

  Tabellen mangler en eller flere verdier i felt som krever verdi i henhold 
  til Noark-4.1. 

    Filnavn       Felt                Frste     Siste   Antall
    ------------  ----------------  --------  --------  -------
    NOARKSAK.XML  sa_dato                108       128        2
    NOARKSAK.XML  sa_status              112                  1
BAM

is($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
