#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id$
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 9;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::PrimaryKey');
}

my $err = Noark::Error::PrimaryKey->new();

isa_ok($err, 'Noark::Error::PrimaryKey');

is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    pk => 'SA.ID',
    file => 'NOARKSAK.XML',
    line => 4,
}), 'Noark::Error::PrimaryKey');
isa_ok($err->add_line({
    pk => 'SA.ID',
    file => 'NOARKSAK.XML',
    line => 24,
}), 'Noark::Error::PrimaryKey');
isa_ok($err->add_line({
    pk => 'SA.ID',
    file => 'NOARKSAK.XML',
    line => 44,
}), 'Noark::Error::PrimaryKey');

# print Dumper $err->{__keys};
# exit;

is_deeply(
    $err->{__keys}, {
        'SA.ID' => {
            'NOARKSAK.XML' => {
                '4' => 1,
                '24' => 1,
                '44' => 1
               }
           }
       },
    "Testing integrity of error hash"
);


can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
  Ugyldig primrnkkel i tabell

  Et felt som utgjorde primrnkkelen i tabellen var ikke definert, til tross 
  for at feltet skal vre avlevert iht. Noark-4.1. 

    Filnavn          Linje  Nkkel                                    
    ------------  --------  ------------------------------------------
    NOARKSAK.XML         4  SA.ID                                     
    NOARKSAK.XML        24  SA.ID                                     
    NOARKSAK.XML        44  SA.ID                                     
BAM

eq_or_diff_text($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
