#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id$
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 9;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::ValidData');
}

my $err = Noark::Error::ValidData->new();

isa_ok($err, 'Noark::Error::ValidData');

is_deeply($err->{__keys}, {}, "Testing integrity of errors");

isa_ok($err->add_line({
    field => 'SA.ID',
    value => 'Hodor is a hunchback of late',
    line => 4,
    file => 'NOARKSAK.XML',
    datatype => 'VARCHAR(10)',
}), 'Noark::Error::ValidData');
isa_ok($err->add_line({
    field => 'SA.ID',
    value => 'Hodor is a hunchback of great',
    line => 14,
    file => 'NOARKSAK.XML',
    datatype => 'VARCHAR(10)',
}), 'Noark::Error::ValidData');
isa_ok($err->add_line({
    field => 'SA.ID',
    value => 'Hodor is a hunchback of fate',
    line => 24,
    file => 'NOARKSAK.XML',
    datatype => 'VARCHAR(10)',
}), 'Noark::Error::ValidData');

# print Dumper $err->{__keys};
# exit;

is_deeply(
    $err->{__keys}, {
        'SA.ID' => {
            'VARCHAR(10)' => {
                'NOARKSAK.XML' => {
                    '4' => {
                        'Hodor is a hunchback of late' => 1
                       },
                    '24' => {
                        'Hodor is a hunchback of fate' => 1
                       },
                    '14' => {
                        'Hodor is a hunchback of great' => 1
                       }
                   }
               }
           }
       },
    "Testing integrity of error hash"
);

# print Dumper $err->to_text(undef, 2);
# exit;

can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
  Ugyldig innhold i attributt

  Et eller flere felt i tabellen hadde ugyldig verdi i forhold til datatypen 
  definert i Noark-4.1. 

    Filnavn       Felt          Datatype      Verdi               Antall
    ------------  ------------  ------------  ----------------  --------
    NOARKSAK.XML  SA.ID         VARCHAR(10)   Hodor is a hunch         1
    NOARKSAK.XML  SA.ID         VARCHAR(10)   Hodor is a hunch         1
    NOARKSAK.XML  SA.ID         VARCHAR(10)   Hodor is a hunch         1
BAM

eq_or_diff_text($err->to_text(undef, 2), $expect_to_text, 'Testing to_text');
