#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id$
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 6;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::ExtraAttribute');
}

my $err = Noark::Error::ExtraAttribute->new(table => 'JOURNPOST');

isa_ok($err, 'Noark::Error::ExtraAttribute');

ok($err->add_attributes(
    {
        attributes => [qw|JP.SAID FOOBAR JP.UTLTIL|],
        table => 'JOURNPOST',
    }), 
   'Testing add attributes');

is_deeply($err->{__attributes}, ['JP.SAID'], 'Verifying attributes');

can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
    2.1.1. Ekstra Attributter funnet

      Et eller flere av attributtene som ikke er er tatt med i NOARKIH har 
      kravtype K=O,O=x. Dette vil si at attributtet er del av en obligatorisk 
      tabell og SKAL inneholde data. Det er i utgangspunktet en alvorlig feil 
      at dette mangler. At attributtene er brukt i tabellene, men ikke er 
      tatt med i NOARKIH er en ytterligere feil. 

      Flgende attributter forekommer i avleveringen, men er ikke tatt med i 
      NOARKIH: 

        Attributt                 Krav type   
        ------------------------  ------------
        JP.SAID                   K=O,O=x     
BAM

eq_or_diff_text($err->to_text("2.1.1.", 4), $expect_to_text, 'Testing to_text');
