#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id$
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 7;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::MissingFileFound');
}

my $err = Noark::Error::MissingFileFound->new();

isa_ok($err, 'Noark::Error::MissingFileFound');

ok($err->add_line({
    deposit_file => 'JOURNPOS.XML',
    noarkih_file => 'JPOST.XML',
    line         => 165,
   }), "Testing add_line"
);
ok($err->add_line({
    noarkih_file => 'NOARKSAK.XML',
    deposit_file => 'HATTIFNASK.XML',
    line         => 12345678,
   }), "Testing add_line"
);

is_deeply(
    $err->{__keys},
    {
        '12345678' => {
            'NOARKSAK.XML' => {
                'HATTIFNASK.XML' => {}
               }
           },
        '165' => {
            'JPOST.XML' => {
                'JOURNPOS.XML' => {}
               }
           }
    },
    " Testing keys"
);
 

can_ok($err, qw|to_text|);
my $expect_to_text = <<BAM;
    2.1.1. Forskjell p filnavn i NOARKIH og i avlevering

    Filnavnet i NOARKIH stemte ikke med filnavnet i avleveringen for flere 
    filer. Filnavnene er: 

      i NOARKIH     Navn i avlevering                    Linje
      ------------  --------------------------------  --------
      JPOST.XML     JOURNPOS.XML                           165
      NOARKSAK.XML  HATTIFNASK.XML                    12345678
BAM

eq_or_diff_text($err->to_text("2.1.1.", 4), $expect_to_text, 'Testing to_text');
