#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id$
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 8;
use Test::Differences;
use Data::Dumper;

BEGIN {
    use_ok('Noark::Error::BrokenDocumentReference');
}

my $err = Noark::Error::BrokenDocumentReference->new();

isa_ok($err, 'Noark::Error::BrokenDocumentReference');

ok($err->add_line(
    {
        file => 'NOARKSAK.XML',
        name => '/2002/03/foobar.pdf',
        line => '3456',
       }
   ), "Testing add_line"
);

can_ok($err, qw|to_text|);

# print $err->to_text("2.1.1.", 4);
# exit;
my $expect_to_text = <<BAM;
    2.1.1. Referanse til dokument som ikke finnes.

      Et sted i fila referereres til et dokument som vi ikke kan finne i 
      avleveringen. 

        Filnavn          Linje  Dokumentnavn                            
        ------------  --------  ----------------------------------------
        NOARKSAK.XML      3456  /2002/03/foobar.pdf                     
BAM

eq_or_diff_text($err->to_text("2.1.1.", 4), $expect_to_text, 'Testing to_text');

ok($err->add_line(
    {
        file => 'NOARKSAK.XML',
        name => '/2002/03/hattifnatt.pdf',
        line => '4444',
       }
   ), "Testing add_line"
);
ok($err->add_line(
    {
        file => 'NOARKSAK.XML',
        name => '/2002/03/karnapp.pdf',
        line => '5555',
       }
   ), "Testing add_line"
);

# print $err->to_text("2.1.1.", 4);
# exit;
my $exptext = <<BBAM;
    2.1.2. Referanse til dokument som ikke finnes.

      Flere steder i fila referereres til dokumenter som vi ikke kan finne i 
      avleveringen. 

        Filnavn          Linje  Dokumentnavn                            
        ------------  --------  ----------------------------------------
        NOARKSAK.XML      3456  /2002/03/foobar.pdf                     
        NOARKSAK.XML      4444  /2002/03/hattifnatt.pdf                 
        NOARKSAK.XML      5555  /2002/03/karnapp.pdf                    
BBAM

eq_or_diff_text(
    $err->to_text("2.1.2.", 4), $exptext, 'Testing to_text'
);
