#!/usr/bin/perl
#-------------------------------------------------------------------------
# $Id: 042.noark_parser_errorlist.t 744 2011-06-21 13:30:25Z tm $
#-------------------------------------------------------------------------

use strict;

use Test::More tests => 20;

BEGIN {
    use_ok('Noark::Parser::ErrorList');
}

my $err = Noark::Parser::ErrorList->new();

isa_ok($err, 'Noark::Parser::ErrorList');

eval {
    $err->add_error();
};

ok($@ =~ /first argument \(error key\) must be defined/, 
   "add_error w/o arguments dies");

use Data::Dumper;

# Peek inside the errorlist object and verify it is emtpy:
ok(!$err->{__errors}, "Verify the list of errors is empty");

$err = $err->add_error('test', 'Noark::Error::DuplicateKey', {
    pk    => 'foobar',
    file  => 'test.xml',
    line  => 1,
    table => 'noarksak',
});
isa_ok($err, 'Noark::Parser::ErrorList');

isa_ok($err->{__errors}, 'HASH');
isa_ok($err->{__errors}->{test}, 'HASH');
is_deeply(
    keys %{$err->{__errors}->{test}}, 
    qw(Noark::Error::DuplicateKey),
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::PotentialDuplicateKey', {
    pk => 'foo    bar',
    norm => 'foobar',
    file => 'test.xml',
    line => 20,
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey 
        Noark::Error::PotentialDuplicateKey 
    )],
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::PrimaryKey', {
    pk => 'SA.ID',
    file => 'test.xml',
    line => 20,
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey 
        Noark::Error::PotentialDuplicateKey
        Noark::Error::PrimaryKey
    )],
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::Null', {
    field => 'foobar',
    file => 'foobar.xml',
    line => 20,
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey 
        Noark::Error::Null
        Noark::Error::PotentialDuplicateKey
        Noark::Error::PrimaryKey
    )],
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::ValidData', {
    field => 'SA.ID',
    file => 'foobar.xml',
    line => 20,
    value => "balbalbalbla",
    datatype => 'VARCHAR(2)',
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey 
        Noark::Error::Null
        Noark::Error::PotentialDuplicateKey
        Noark::Error::PrimaryKey
        Noark::Error::ValidData
    )],
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::DuplicateUnique', {
    field => 'SA.ID',
    value => '20110606',
    file => 'foobar.xml',
    lines => [20, 40],
    datatype => 'INTEGER(10)',
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey
        Noark::Error::DuplicateUnique
        Noark::Error::Null
        Noark::Error::PotentialDuplicateKey
        Noark::Error::PrimaryKey
        Noark::Error::ValidData
    )],
    "Verifying list of errors in errorlist"
);

$err = $err->add_error('test', 'Noark::Error::ForeignKey', {
    field     => 'sa_type',
    table     => 'noarksak',
    ref_field => 'st_type',
    ref_table => 'sakstype',
    value     => 'foobar',
    requirement => 'O => O',
});
isa_ok($err, 'Noark::Parser::ErrorList');

is_deeply(
    [sort keys %{$err->{__errors}->{test}}],
    [qw(Noark::Error::DuplicateKey
        Noark::Error::DuplicateUnique
        Noark::Error::ForeignKey
        Noark::Error::Null
        Noark::Error::PotentialDuplicateKey
        Noark::Error::PrimaryKey
        Noark::Error::ValidData
    )],
    "Verifying list of errors in errorlist"
);
