#!/usr/bin/perl
#---------------------------------------------------------------------
# $Id: 045.noark.parser.t 780 2011-06-23 14:45:01Z tm $
#---------------------------------------------------------------------
# Automatic tester for ArkN4.

use strict;

use Time::HiRes qw(time);
use Data::Dumper;

use Test::Differences;
use Test::More tests => 30;

use Noark::Config qw($config);

BEGIN {
    use_ok('Noark::Parser');
    use_ok('Noark::Parser::Tabellinfo');
    use_ok('Noark::Parser::TabellinfoList');
}

# Testing noarkih first
my $nih = Noark::Parser->new(
    dir       => './uttrekk/test_lc_xml/',
    xmldir    => 'DATA',
    docdir    => 'DOKUMENT',
    reportdir => 'RAPPORT',
    sqldir    => './database'
);
isa_ok($nih, 'Noark::Parser');

isa_ok($nih->get_db_errorlist(), 'Noark::Parser::ErrorList');


is($nih->_find_noarkih(), './uttrekk/test_lc_xml/noarkih.xml', 
   "Testing that _find_noarkih finds lowercase file");

my $parser = Noark::Parser->new(
    dir    => "./uttrekk/test",
    xmldir    => 'DATA',
    docdir    => 'DOKUMENT',
    reportdir => 'RAPPORT',
    sqldir => "./database");

isa_ok($parser, 'Noark::Parser');
can_ok('Noark::Parser', 
       qw(
          build_sql 
          get_data_and_insert
          get_db_handle 
          get_eksportinfo
          get_noark_schema
          get_tabellinfo_list
          get_xmlmeta_info 
          handle_attributter 
          handle_fil 
          handle_ti_fildeler
          handle_ti_tabell
          make_primary_key_string
          new
          set_noarkih_file       
          verify_attributes
          verify_or_repair_foreign_key_integrity
         ));

is($parser->_find_noarkih(), './uttrekk/test/NOARKIH.XML', 
   "Testing that _find_noarkih finds uppercase file");

my $name = "NOARKSAK.TAB";
my @attr = ( "SA.DATO", "SA.ANTJP", "SA.ARKDEL", "SA.SAAR", "SA.ID", 
             "SA.JENHET", "SA.SEKNR", "SA.PAPIR", "SA.SISTEJP", "SA.ADMID",
             "SA.TYPE", "SA.TITTEL", "SA.ANSVID", "SA.STATUS", "SA.TGKODE",
             "SA.U1", "SA.TGGRUPPE", "SA.UOFF", "SA.BEVTID", "SA.KASSKODE",
             "SA.PROSJEKT", "SA.KASSDATO", "SA.FRARKDEL", );
my $sql = "INSERT INTO noarksak (sa_dato, sa_antjp, sa_arkdel, sa_saar, sa_id, sa_jenhet, sa_seknr, sa_papir, sa_sistejp, sa_admid, sa_type, sa_tittel, sa_ansvid, sa_status, sa_tgkode, sa_u1, sa_tggruppe, sa_uoff, sa_bevtid, sa_kasskode, sa_prosjekt, sa_kassdato, sa_frarkdel) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

#-----------------------------------------------------------------------------
# Tester Noark::Parser::Tabellinfo og TabellinfoList
#-----------------------------------------------------------------------------

my $info_list = $parser->get_tabellinfo_list;
isa_ok($info_list, 'Noark::Parser::TabellinfoList');
can_ok(ref($info_list), qw(new get_tabellinfo_by_name));

my $tinfo = $info_list->get_tabellinfo_by_name('NOARKSAK');
isa_ok($tinfo, 'Noark::Parser::Tabellinfo');
can_ok(ref($tinfo), qw(
                       new 
                       get_table_name 
                       set_table_name 
                       get_ih_number_of_files
                       get_files_ref 
                       get_line_number 
                       increment_counter
                       get_counter 
                      ));

ok($tinfo->get_table_name() eq 'NOARKSAK', "Table name eq NOARKSAK");
ok($tinfo->get_ih_number_of_files() == 2, "Number of files is correct");

is($parser->build_sql($name, \@attr), $sql, 
   "testing 'Noark::Parser::build_sql()'");

# my $xp = $parser->get_parser();
# isa_ok($xp, 'XML::LibXML');

my $filemap = $parser->get_filemap();
# my $doc = $xp->parse_file($filemap->get_file_by_name('TGMEDLEM.XML'));
# isa_ok($doc, 'XML::LibXML::Document');


my $tab = $info_list->get_tabellinfo_by_name('TGMEDLEM');
my $files1 = [
              {
               'TI.ANTPOSTER' => '64',
               'TI.FILNAVN' => 'TGMEDLEM.XML'
              }
             ];
eq_or_diff($tab->get_files_ref, $files1,"Getting correct files in tabellinfo");

my $attr1 = [
             'PG.PEID',
             'PG.GRUPPEID',
             'PG.MEDKOD',
             'PG.INNMAV',
             'PG.FRADATO'
            ];

eq_or_diff($tab->get_attributes, $attr1, "Getting correct attributes");
ok ($tab->get_line_number == 505, "Getting correct line number");

my $doc = XML::Twig->new();
$doc->parsefile($filemap->get_file_by_name('TGMEDLEM.XML'));
my $root = $doc->root;
my @elem = $root->getElementsByTagName($tab->{'TI.TABELL'});

ok(test_number_of_elements(), 
    "testing consistecy of numbering check.");

my @pksres = ('102125', '108125', '108130', '111125', '111127', '114125',
              '115125', '116125', '117125', '118125', '119125', '108138', 
              '111138', '119130', '114130', '118130', '115130', '117130', 
              '116130', '108139', '111139', '120125', '120140', '121125', 
              '121141', '122125', '123125', '123143', '124125', '122142', 
              '124140', '124141', '123130', '119141', '119138', '111130', 
              '111140', '111141', '111142', '111143', '186125', '1860', 
              '1150', '115184', '1190', '1190', '188125', '186182', '114182',
              '1170', '1110', '111180', '111177', '111183', '111184', 
              '111182', '111181', '111179', '1110', '111178', '1110', 
              '111176', '191125', '122140',
             );

my @test = ();
for (@elem) {
    my %atr = map { $_->name => $_->text } $_->children;
    my ($pk, $what) = $parser->make_primary_key_string('TGMEDLEM', \%atr);
    push(@test, $pk);
}
 
eq_or_diff(\@test, \@pksres,
          "testing calculation of primary key strings");


#---------------------------------------------------------------------
# Testing compare_attributes
#---------------------------------------------------------------------

my $tname = 'NOARKSAK.TAB';

my $info = {
          'FILES' => [
                       {
                         'VALID' => 1,
                         'TI.ANTPOSTER' => 8,
                         'TI.FILNAVN' => 'sak.xml'
                       }
                     ],
          'FILECOUNT' => 1,
          'COUNTEDROWS' => 8,
          'ATTRIBUTTER' => [
                             'SA.ID',
                             'SA.SAAR',
                             'SA.SEKNR',
                             'SA.PAPIR',
                             'SA.DATO',
                             'SA.TITTEL',
                             'SA.U1',
                             'SA.STATUS',
                             'SA.ARKDEL',
                             'SA.TYPE',
                             'SA.JENHET',
                             'SA.ADMID',
                             'SA.ANSVID',
                             'SA.TGKODE',
                             'SA.UOFF',
                             'SA.TGGRUPPE',
                             'SA.SISTEJP',
                             'SA.ANTJP',
                             'SA.BEVTID',
                             'SA.KASSKODE',
                             'SA.KASSDATO',
                             'SA.PROSJEKT',
                             'SA.PRES',
                             'SA.FRARKDEL'
                           ],
          'TI.ANTFILER' => '1',
          'LINE' => 547,
          'TI.TABELL' => 'NOARKSAK'
        };


my $xfile = 'NOARKSAK.XML';
my $xline = 4;


my $noark = [
          'SA.ID',
          'SA.SAAR',
          'SA.SEKNR',
          'SA.PAPIR',
          'SA.DATO',
          'SA.TITTEL',
          'SA.U1',
          'SA.STATUS',
          'SA.ARKDEL',
          'SA.TYPE',
          'SA.JENHET',
          'SA.ADMID',
          'SA.ANSVID',
          'SA.TGKODE',
          'SA.UOFF',
          'SA.TGGRUPPE',
          'SA.SISTEJP',
          'SA.ANTJP',
          'SA.BEVTID',
          'SA.KASSKODE',
          'SA.KASSDATO',
          'SA.PROSJEKT',
          'SA.PRES',
          'SA.FRARKDEL'
        ];

my $row = {
          'SA.ID'       => '200200011',
          'SA.SAAR'     => '2002',
          'SA.SEKNR'    => '11',
          'SA.PAPIR'    => '1',
          'SA.DATO'     => '20020514',
          'SA.TITTEL'   => 'Tester nok en gang en gang',
          'SA.U1'       => '0',
          'SA.STATUS'   => 'A',
          'SA.ARKDEL'   => 'INGEN',
          'SA.ADMID'    => '70003',
          'SA.ANSVID'   => '150006',
          'SA.TGGRUPPE' => '0',
          'SA.SISTEJP'  => '20020515',
          'SA.ANTJP'    => '5',
          'SA.KASSKODE' => 'B',
        };

my $argse = [
    '200200011',
    '2002',
    '11',
    '1',
    '20020514',
    'Tester nok en gang en gang',
    '0',
    'A',
    'INGEN',
    undef,
    undef,
    '70003',
    '150006',
    undef,
    undef,
    '0',
    '20020515',
    '5',
    undef,
    'B',
    undef,
    undef,
    undef,
    undef
];

my $argss = $parser->verify_attributes(
    row   => $row,   
    noark => $noark,
    table => $tname, 
    info  => $info,
    file  => $xfile, 
    line  => $xline
);

# print Dumper $argss;
# exit;
# sub compare_lists {
#     my ($one, $two) = @_;
    
#     return 0 unless (scalar(@$one) == scalar(@$two));
    
#     for (my $i = 0; $i < scalar(@$one)-1; $i++) {
#         next if (not defined $one->[$i] && not defined $two->[$i]);
#         return 0 unless $one->[$i] eq $two->[$i];
#     } 
#     return 1;
# }

# ok(compare_lists($argse, $argss), "Testing result from compare_attributes");

is_deeply($argss, $argse, "testing result from compare_attributes");

sub test_number_of_elements {

    my $file = $filemap->get_file_by_name('TGMEDLEM.XML');
    my $count = qx(cat $file | grep '<TGMEDLEM>' | wc -l);
    chomp($count);

    my $tabc = 0;
    for (@{$tab->{FILES}}) {
        $tabc += $_->{'TI.ANTPOSTER'};
    }
    
    return 1 if (scalar(@elem) == $count && $tabc == $count);
    return 0;
}
# my $attr = $parser->get_attributes_from_element()
# print Dumper($tab);


#----------------------------------------------------------------------------
# Testing: __split_datatype_and_size
#----------------------------------------------------------------------------
my ($type, $size) = $parser->__split_datatype_and_size('VARCHAR(40)');
ok($type eq 'VARCHAR', 'Testing __split_datatype_and_size');
ok($size eq 40, 'Testing __split_datatype_and_size');

my ($type2, $size2) = $parser->__split_datatype_and_size('VARCHAR');
ok($type2 eq 'VARCHAR', 'Testing __split_datatype_and_size');
ok(!defined($size2), 'Testing __split_datatype_and_size');

#-----------------------------------------------------------------------------
# Testing: __get_dummy_varchar
#-----------------------------------------------------------------------------
# Noark::Parser::__get_dummy_varchar(undef, 10, "XXXXXXXXAA"), "\n";
ok($parser->__get_dummy_varchar(10, "XXXXXXXXAA") eq 'XXXXXXXWXX',
  'Testing __get_dummy_varchar');
ok($parser->__get_dummy_varchar(4) eq 'XXXX', 'Testing __get_dummy_varchar');

# Testing wash_attribute_values

my @fixture = (
    [
        {
            'OT.KODE' => 'US',
            'OT.BETEGN' => "\r\n      Uspesifiserte sekundrkoder, benyttes ved konvertering fra\r\n       Noark-3"
        },
        {
            'OT.KODE' => 'US',
            'OT.BETEGN' => "Uspesifiserte sekundrkoder, benyttes ved konvertering fra Noark-3"
        },
    ],
    [
        {
            'OT.KODE' => 'NO   PO',
            'OT.BETEGN' => "Uspesifiserte      benyttes ved konvertering     "
        },
        {
            'OT.KODE' => 'NO   PO',
            'OT.BETEGN' => "Uspesifiserte      benyttes ved konvertering",
        },
    ],
);

for my $f (@fixture) {
    is_deeply($f->[1], $parser->wash_attribute_values($f->[0]));    
}
