#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id: 050.noark_report.t 579 2011-05-31 12:15:39Z tm $
#-----------------------------------------------------------------------------
# Tests for Noark::Report

use strict;
use warnings;

use Data::Dumper;
use Test::Differences;
use Test::More tests => 5;
use IO::File;

BEGIN {
    use_ok('Noark::Report');
    use_ok('Noark::Error');
    use_ok('Noark::Error::ExtraAttribute');
}

my $report = Noark::Report->new(format => 'txt',
                                name   => '050.test',
                                dir    => '/tmp');

isa_ok($report, 'Noark::Report::Text');

my $name = 'Duplikat verdi for felt som er UNIQUE';
my $text = qq{Verdien til feltet 'testefelt', med datatypen 'testetype', skal }
    .  q{vre unikt }
    .  q{i henhold til kravspesifikasjonen til NOARK-4 del 2, }
    .  q{kapittel 14.2.23. Det forekom et eller flere felt som }
    .  q{innehold duplikate verdier.};

my $error = Noark::Error->new(name => $name, text => $text, 
                              file => 'FOOBAR.XML');

$error->set_list_labels(qw(Filnavn Linje Beskrivelse));
$error->set_list_label_lengths(16, 5, 51);

for (1024..1033) {
    $error->add_listing('FOOBAR.XML', $_, 
                        "Foobar argument PS=$_ er ikke unik");
} 

$report->write_common_error($error, undef, undef);

my $fh = IO::File->new('/tmp/050.test.txt', 'r') or die("Oops: $!");
my $got = do { local $/; <$fh> };
$fh->close() or die("Oops unlink: $!");

# unlink('/tmp/050.test.txt') or die("Oops close: $!");
system('cat /dev/null > /tmp/050.test.txt');
seek($report->{REPORT}, 0, 0);

my $answer = <<'EMSG';
    0.0.1. Duplikat verdi for felt som er UNIQUE

      Verdien til feltet 'testefelt', med datatypen 'testetype', skal vre
      unikt i henhold til kravspesifikasjonen til NOARK-4 del 2, kapittel
      14.2.23. Det forekom et eller flere felt som innehold duplikate
      verdier.

        Filnavn           Linje  Beskrivelse                                        
        ----------------  -----  ---------------------------------------------------
        FOOBAR.XML        1024   Foobar argument PS=1024 er ikke unik               
        FOOBAR.XML        1025   Foobar argument PS=1025 er ikke unik               
        FOOBAR.XML        1026   Foobar argument PS=1026 er ikke unik               
        FOOBAR.XML        1027   Foobar argument PS=1027 er ikke unik               
        FOOBAR.XML        1028   Foobar argument PS=1028 er ikke unik               
        FOOBAR.XML        1029   Foobar argument PS=1029 er ikke unik               
        FOOBAR.XML        1030   Foobar argument PS=1030 er ikke unik               
        FOOBAR.XML        1031   Foobar argument PS=1031 er ikke unik               
        FOOBAR.XML        1032   Foobar argument PS=1032 er ikke unik               
        FOOBAR.XML        1033   Foobar argument PS=1033 er ikke unik               


EMSG

eq_or_diff($got, $answer, 'Testing output from error message');


#-----------------------------------------------------------------------------
# Tester ny extra attributes error.

# my $extra = Noark::Analyzer::ExtraAttributesError->new();
# 
# $extra->add_attributes([qw(BLANG DANG OG_IKKE_HVA DU_VENTET)]);
# 
# $report->write_extra_attribute_error($extra, undef);
# 
# my $fh2 = IO::File->new('/tmp/050.test.txt', 'r') or die("Oops: $!");
# $got = do { local $/; <$fh2> };
# $fh2->close() or die("Oops unlink: $!");
# 
# my $expected = <<EOF;
#     0.0.2. Ekstra Attributter funnet
# 
#       Flgende attributter forekommer i avleveringen, men finnes ikke i 
#       NOARKIH: 
# 
#         Ekstra Attributter
#         ------------------
#         BLANG
#         DANG
#         OG_IKKE_HVA
#         DU_VENTET
# 
# EOF
# 
# eq_or_diff($got, $expected, 'Tester __format text i Report::Text');
# 
# unlink('/tmp/050.test.txt');
