#!/usr/bin/perl
#------------------------------------------------------------------------
# $id$
#------------------------------------------------------------------------

use strict;
use warnings;

use Test::More tests => 12;

BEGIN {
    use_ok 'Noark::Error::BadOrderMsg';
}

is(undef, Noark::Error::BadOrderMsg->new(), "Empty BadOrderMsg object");

my @fixture = (
    {
        'msg' => 'bad order of Elements Found=[AM.IHTYPE,AM.U1,AM.BEHANSV,'
               . 'AM.ADMKORT,AM.SBHINIT,AM.JENHET,AM.AVSKM,AM.AVSKDATO] '
               . 'RE=[((AM.NAVN)(AM.IHTYPE)(AM.U1)?(AM.BEHANSV)?(AM.ADMKORT)'
               . '(AM.SBHINIT)(AM.JENHET)?(AM.AVSKM)?(AM.AVSKDATO)?'
               . '(AM.AVSAVDOK)?(AM.BESVARDOK)?)]',
        'FOUNDLIST' => [
            'AM.IHTYPE',
            'AM.U1',
            'AM.BEHANSV',
            'AM.ADMKORT',
            'AM.SBHINIT',
            'AM.JENHET',
            'AM.AVSKM',
            'AM.AVSKDATO',
           ],
        'MISSING' => {
            'AM.NAVN' => 1
           },
        'ORDERED' => [
            'AM.NAVN',
            'AM.IHTYPE',
            'AM.U1',
            'AM.BEHANSV',
            'AM.ADMKORT',
            'AM.SBHINIT',
            'AM.JENHET',
            'AM.AVSKM',
            'AM.AVSKDATO',
            'AM.AVSAVDOK',
            'AM.BESVARDOK'
           ],
        'MANDATORY' => {
            'AM.SBHINIT' => 1,
            'AM.NAVN' => 1,
            'AM.IHTYPE' => 1,
            'AM.ADMKORT' => 1
           },
    },
    {
         'msg' => 'bad order of Elements Found=[SA.SAAR,SA.SEKNR,SA.PAPIR,'
                . 'SA.DATO,SA.TITTEL,SA.OFFTITTEL,SA.U1,SA.ARKDEL,SA.ASTATUS,'
                . 'SA.JENHET,SA.ADMKORT,SA.ANSVINIT,JOURNPOST.JO] '
                . 'RE=[((SA.SAAR)(SA.SEKNR)(SA.PAPIR)?(SA.DATO)(SA.TITTEL)'
                . '(SA.OFFTITTEL)?(SA.U1)?(SA.ARKDEL)?(SA.ASTATUS)(SA.JENHET)?'
                . '(SA.ADMKORT)(SA.ANSVINIT)(SA.TGKODE)?(SA.UOFF)?'
                . '(KLASSERING.JO)+(JOURNPOST.JO))]',
         'FOUNDLIST' => [
             'SA.SAAR',
             'SA.SEKNR',
             'SA.PAPIR',
             'SA.DATO',
             'SA.TITTEL',
             'SA.OFFTITTEL',
             'SA.U1',
             'SA.ARKDEL',
             'SA.ASTATUS',
             'SA.JENHET',
             'SA.ADMKORT',
             'SA.ANSVINIT',
             'JOURNPOST.JO'
            ],
         'MISSING' => {
             'KLASSERING.JO' => 1,
            },
         'ORDERED' => [
             'SA.SAAR',
             'SA.SEKNR',
             'SA.PAPIR',
             'SA.DATO',
             'SA.TITTEL',
             'SA.OFFTITTEL',
             'SA.U1',
             'SA.ARKDEL',
             'SA.ASTATUS',
             'SA.JENHET',
             'SA.ADMKORT',
             'SA.ANSVINIT',
             'SA.TGKODE',
             'SA.UOFF',
             'KLASSERING.JO',
             'JOURNPOST.JO'
            ],
         'MANDATORY' => {
             'SA.ASTATUS' => 1,
             'SA.TITTEL' => 1,
             'SA.SAAR' => 1,
             'SA.SEKNR' => 1,
             'SA.ANSVINIT' => 1,
             'SA.ADMKORT' => 1,
             'KLASSERING.JO' => 1,
             'JOURNPOST.JO' => 1,
             'SA.DATO' => 1
            },
     },
);

for my $item (@fixture) {

    my $bom = Noark::Error::BadOrderMsg->new(msg => $item->{msg}); 
    isa_ok($bom, 'Noark::Error::BadOrderMsg');
    for my $k (keys %$item) {
        next if $k eq 'msg';
        #print $k;
        is_deeply($bom->{$k}, $item->{$k}, "Testing '$k' parsed correctly");
    }

}
