#!/usr/bin/perl
#-----------------------------------------------------------------------------
# $Id: 065.analyzer_documents.t 766 2011-06-22 10:56:42Z tm $
#-----------------------------------------------------------------------------

use strict;
use warnings;

use Data::Dumper;
use Test::More tests => 10;
use Test::Differences;

use Noark::Config qw($config);
use Noark::Analyzer;

my $an = Noark::Analyzer->new(
    dir    => 'uttrekk/test.dokref',
    xmldir    => 'DATA',
    docdir    => 'DOKUMENT',
    reportdir => 'RAPPORT',
    sqldir => './database',
    dtddir => './dtd',
    usedb  => 0
);

# This needs to be initialized: It is initialized in 'are_files_valid'
$an->{METAINFO}->{'DOKVERSJON.TAB'} = {}; 
ok($an->is_file_valid('./uttrekk/test.dokref/DATA/DOKVERS.XML'),
   'Test: is DOKVERS.XML valid');

is($an->get_documents_mentioned(), 20, 
   'Test correct number of documents counted DOKVERSJON');
is($an->get_documents_seen(), 50,
   'Test correct number of documents in directories');

my @seen = sort $an->get_documents_seen_list();
my $expected2 = [
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/281.TXT',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/282.pdf',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/283.XML',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/284.xml',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/285.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/286.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/287.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/288.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/289.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/17/290.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/281.TXT',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/282.pdf',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/283.XML',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/284.xml',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/285.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/286.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/287.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/288.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/289.txt',
          'uttrekk/test.dokref/DOKUMENT/2011/05/30/290.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/06/01/401.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/06/01/402.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/06/01/403.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/06/01/404.PDF',
          'uttrekk/test.dokref/DOKUMENT/2011/06/01/405.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/281.TXT',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/282.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/283.XML',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/284.xml',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/285.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/286.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/287.txt',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/288.txt',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/289.txt',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/290.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/401.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/402.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/403.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/404.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter001/405.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/291.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/292.PDF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/293.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/294.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/295.pdf',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/296.tif',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/297.TIF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/298.TIF',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/299.tif',
          'uttrekk/test.dokref/DOKUMENT/Dokumenter002/300.xml'
        ];

eq_or_diff(\@seen, $expected2, "Test get_documents_seen_list");

my @extra = $an->get_documents_extra_list();

is(scalar @extra, 43, 'Test if extra count is corrent');

my $expected_1 = { 'TXT'    => 2,
                   'RA-PDF' => 11,
                   'XML'    => 1,
                   'TIFF'   => 6,
                  };

eq_or_diff($an->get_document_filetypes(), $expected_1,
          'Test document distribution');

is($an->get_documents_found, 7, 'Test get_documents_found');
is($an->get_documents_missing, 13, 'Test get_documents_missing');

my @found_1 = $an->get_documents_found_list;
my @found_2 = $an->get_documents_missing_list;
is(scalar @found_1, 7,  'Test get_documents_found_list');
is(scalar @found_2, 13, 'Test get_documents_missing_list');


# print Dumper $an->{METAINFO};
